Enum jumpy::core::physics::collisions::rapier::RigidBodyType
pub enum RigidBodyType {
Dynamic = 0,
Fixed = 1,
KinematicPositionBased = 2,
KinematicVelocityBased = 3,
}Expand description
The status of a body, governing the way it is affected by external forces.
Variants
Dynamic = 0
A RigidBodyType::Dynamic body can be affected by all external forces.
Fixed = 1
A RigidBodyType::Fixed body cannot be affected by external forces.
KinematicPositionBased = 2
A RigidBodyType::KinematicPositionBased body cannot be affected by any external forces but can be controlled
by the user at the position level while keeping realistic one-way interaction with dynamic bodies.
One-way interaction means that a kinematic body can push a dynamic body, but a kinematic body cannot be pushed by anything. In other words, the trajectory of a kinematic body can only be modified by the user and is independent from any contact or joint it is involved in.
KinematicVelocityBased = 3
A RigidBodyType::KinematicVelocityBased body cannot be affected by any external forces but can be controlled
by the user at the velocity level while keeping realistic one-way interaction with dynamic bodies.
One-way interaction means that a kinematic body can push a dynamic body, but a kinematic body cannot be pushed by anything. In other words, the trajectory of a kinematic body can only be modified by the user and is independent from any contact or joint it is involved in.
Implementations
impl RigidBodyType
impl RigidBodyType
pub fn is_dynamic(self) -> bool
pub fn is_dynamic(self) -> bool
Is this rigid-body dynamic (i.e. can move and be affected by forces)?
pub fn is_kinematic(self) -> bool
pub fn is_kinematic(self) -> bool
Is this rigid-body kinematic (i.e. can move but is unaffected by forces)?