Struct jumpy::core::physics::collisions::rapier::ActiveCollisionTypes
pub struct ActiveCollisionTypes {
bits: u16,
}Expand description
Flags affecting whether or not collision-detection happens between two colliders depending on the type of rigid-bodies they are attached to.
Fields
bits: u16Implementations
impl ActiveCollisionTypes
impl ActiveCollisionTypes
pub const DYNAMIC_DYNAMIC: ActiveCollisionTypes = _
pub const DYNAMIC_DYNAMIC: ActiveCollisionTypes = _
Enable collision-detection between a collider attached to a dynamic body and another collider attached to a dynamic body.
pub const DYNAMIC_KINEMATIC: ActiveCollisionTypes = _
pub const DYNAMIC_KINEMATIC: ActiveCollisionTypes = _
Enable collision-detection between a collider attached to a dynamic body and another collider attached to a kinematic body.
pub const DYNAMIC_FIXED: ActiveCollisionTypes = _
pub const DYNAMIC_FIXED: ActiveCollisionTypes = _
Enable collision-detection between a collider attached to a dynamic body and another collider attached to a fixed body (or not attached to any body).
pub const KINEMATIC_KINEMATIC: ActiveCollisionTypes = _
pub const KINEMATIC_KINEMATIC: ActiveCollisionTypes = _
Enable collision-detection between a collider attached to a kinematic body and another collider attached to a kinematic body.
pub const KINEMATIC_FIXED: ActiveCollisionTypes = _
pub const KINEMATIC_FIXED: ActiveCollisionTypes = _
Enable collision-detection between a collider attached to a kinematic body and another collider attached to a fixed body (or not attached to any body).
pub const FIXED_FIXED: ActiveCollisionTypes = _
pub const FIXED_FIXED: ActiveCollisionTypes = _
Enable collision-detection between a collider attached to a fixed body (or not attached to any body) and another collider attached to a fixed body (or not attached to any body).
pub const fn empty() -> ActiveCollisionTypes
pub const fn empty() -> ActiveCollisionTypes
Returns an empty set of flags.
pub const fn all() -> ActiveCollisionTypes
pub const fn all() -> ActiveCollisionTypes
Returns the set containing all flags.
pub const fn from_bits(bits: u16) -> Option<ActiveCollisionTypes>
pub const fn from_bits(bits: u16) -> Option<ActiveCollisionTypes>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u16) -> ActiveCollisionTypes
pub const fn from_bits_truncate(bits: u16) -> ActiveCollisionTypes
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: u16) -> ActiveCollisionTypes
pub const unsafe fn from_bits_unchecked(bits: u16) -> ActiveCollisionTypes
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
pub const fn intersects(&self, other: ActiveCollisionTypes) -> bool
pub const fn intersects(&self, other: ActiveCollisionTypes) -> bool
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: ActiveCollisionTypes) -> bool
pub const fn contains(&self, other: ActiveCollisionTypes) -> bool
Returns true if all of the flags in other are contained within self.
pub fn insert(&mut self, other: ActiveCollisionTypes)
pub fn insert(&mut self, other: ActiveCollisionTypes)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: ActiveCollisionTypes)
pub fn remove(&mut self, other: ActiveCollisionTypes)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: ActiveCollisionTypes)
pub fn toggle(&mut self, other: ActiveCollisionTypes)
Toggles the specified flags in-place.
pub fn set(&mut self, other: ActiveCollisionTypes, value: bool)
pub fn set(&mut self, other: ActiveCollisionTypes, value: bool)
Inserts or removes the specified flags depending on the passed value.
pub const fn intersection(
self,
other: ActiveCollisionTypes,
) -> ActiveCollisionTypes
pub const fn intersection( self, other: ActiveCollisionTypes, ) -> ActiveCollisionTypes
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
pub const fn union(self, other: ActiveCollisionTypes) -> ActiveCollisionTypes
pub const fn union(self, other: ActiveCollisionTypes) -> ActiveCollisionTypes
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
pub const fn difference(
self,
other: ActiveCollisionTypes,
) -> ActiveCollisionTypes
pub const fn difference( self, other: ActiveCollisionTypes, ) -> ActiveCollisionTypes
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
pub const fn symmetric_difference(
self,
other: ActiveCollisionTypes,
) -> ActiveCollisionTypes
pub const fn symmetric_difference( self, other: ActiveCollisionTypes, ) -> ActiveCollisionTypes
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
pub const fn complement(self) -> ActiveCollisionTypes
pub const fn complement(self) -> ActiveCollisionTypes
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.
impl ActiveCollisionTypes
impl ActiveCollisionTypes
pub fn test(self, rb_type1: RigidBodyType, rb_type2: RigidBodyType) -> bool
pub fn test(self, rb_type1: RigidBodyType, rb_type2: RigidBodyType) -> bool
Test whether contact should be computed between two rigid-bodies with the given types.