Struct jumpy::core::physics::collisions::rapier::ColliderChanges
pub struct ColliderChanges {
bits: u32,
}Expand description
Flags describing how the collider has been modified by the user.
Fields
bits: u32Implementations
impl ColliderChanges
impl ColliderChanges
pub const MODIFIED: ColliderChanges = _
pub const MODIFIED: ColliderChanges = _
Flag indicating that any component of the collider has been modified.
pub const LOCAL_MASS_PROPERTIES: ColliderChanges = _
pub const LOCAL_MASS_PROPERTIES: ColliderChanges = _
Flag indicating that the density or mass-properties of this collider was changed.
pub const PARENT: ColliderChanges = _
pub const PARENT: ColliderChanges = _
Flag indicating that the ColliderParent component of the collider has been modified.
pub const POSITION: ColliderChanges = _
pub const POSITION: ColliderChanges = _
Flag indicating that the ColliderPosition component of the collider has been modified.
pub const GROUPS: ColliderChanges = _
pub const GROUPS: ColliderChanges = _
Flag indicating that the collision groups of the collider have been modified.
pub const SHAPE: ColliderChanges = _
pub const SHAPE: ColliderChanges = _
Flag indicating that the ColliderShape component of the collider has been modified.
pub const TYPE: ColliderChanges = _
pub const TYPE: ColliderChanges = _
Flag indicating that the ColliderType component of the collider has been modified.
pub const PARENT_EFFECTIVE_DOMINANCE: ColliderChanges = _
pub const PARENT_EFFECTIVE_DOMINANCE: ColliderChanges = _
Flag indicating that the dominance groups of the parent of this collider have been modified.
This flags is automatically set by the PhysicsPipeline when the RigidBodyChanges::DOMINANCE
or RigidBodyChanges::TYPE of the parent rigid-body of this collider is detected.
pub const ENABLED_OR_DISABLED: ColliderChanges = _
pub const ENABLED_OR_DISABLED: ColliderChanges = _
Flag indicating that whether or not the collider is enabled was changed.
pub const fn empty() -> ColliderChanges
pub const fn empty() -> ColliderChanges
Returns an empty set of flags.
pub const fn all() -> ColliderChanges
pub const fn all() -> ColliderChanges
Returns the set containing all flags.
pub const fn from_bits(bits: u32) -> Option<ColliderChanges>
pub const fn from_bits(bits: u32) -> Option<ColliderChanges>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u32) -> ColliderChanges
pub const fn from_bits_truncate(bits: u32) -> ColliderChanges
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: u32) -> ColliderChanges
pub const unsafe fn from_bits_unchecked(bits: u32) -> ColliderChanges
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
pub const fn intersects(&self, other: ColliderChanges) -> bool
pub const fn intersects(&self, other: ColliderChanges) -> bool
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: ColliderChanges) -> bool
pub const fn contains(&self, other: ColliderChanges) -> bool
Returns true if all of the flags in other are contained within self.
pub fn insert(&mut self, other: ColliderChanges)
pub fn insert(&mut self, other: ColliderChanges)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: ColliderChanges)
pub fn remove(&mut self, other: ColliderChanges)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: ColliderChanges)
pub fn toggle(&mut self, other: ColliderChanges)
Toggles the specified flags in-place.
pub fn set(&mut self, other: ColliderChanges, value: bool)
pub fn set(&mut self, other: ColliderChanges, value: bool)
Inserts or removes the specified flags depending on the passed value.
pub const fn intersection(self, other: ColliderChanges) -> ColliderChanges
pub const fn intersection(self, other: ColliderChanges) -> ColliderChanges
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
pub const fn union(self, other: ColliderChanges) -> ColliderChanges
pub const fn union(self, other: ColliderChanges) -> ColliderChanges
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
pub const fn difference(self, other: ColliderChanges) -> ColliderChanges
pub const fn difference(self, other: ColliderChanges) -> ColliderChanges
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
pub const fn symmetric_difference(
self,
other: ColliderChanges,
) -> ColliderChanges
pub const fn symmetric_difference( self, other: ColliderChanges, ) -> ColliderChanges
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
pub const fn complement(self) -> ColliderChanges
pub const fn complement(self) -> ColliderChanges
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.
impl ColliderChanges
impl ColliderChanges
pub fn needs_broad_phase_update(self) -> bool
pub fn needs_broad_phase_update(self) -> bool
Do these changes justify a broad-phase update?
pub fn needs_narrow_phase_update(self) -> bool
pub fn needs_narrow_phase_update(self) -> bool
Do these changes justify a narrow-phase update?