Struct jumpy::core::physics::collisions::rapier::ContactManifoldData
pub struct ContactManifoldData {
pub rigid_body1: Option<RigidBodyHandle>,
pub rigid_body2: Option<RigidBodyHandle>,
pub solver_flags: SolverFlags,
pub normal: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>,
pub solver_contacts: Vec<SolverContact>,
pub relative_dominance: i16,
pub user_data: u32,
}Expand description
A contact manifold between two colliders.
A contact manifold describes a set of contacts between two colliders. All the contact part of the same contact manifold share the same contact normal and contact kinematics.
Fields
rigid_body1: Option<RigidBodyHandle>The first rigid-body involved in this contact manifold.
rigid_body2: Option<RigidBodyHandle>The second rigid-body involved in this contact manifold.
solver_flags: SolverFlagsFlags used to control some aspects of the constraints solver for this contact manifold.
normal: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>The world-space contact normal shared by all the contact in this contact manifold.
solver_contacts: Vec<SolverContact>The contacts that will be seen by the constraints solver for computing forces.
relative_dominance: i16The relative dominance of the bodies involved in this contact manifold.
user_data: u32A user-defined piece of data.
Implementations
impl ContactManifoldData
impl ContactManifoldData
pub fn num_active_contacts(&self) -> usize
pub fn num_active_contacts(&self) -> usize
Number of actives contacts, i.e., contacts that will be seen by the constraints solver.