Struct jumpy::core::physics::collisions::rapier::SharedShape
source · pub struct SharedShape(pub Arc<dyn Shape>);Expand description
The shape of a collider.
Tuple Fields
0: Arc<dyn Shape>Implementations
sourcepub fn new(shape: impl Shape) -> SharedShape
pub fn new(shape: impl Shape) -> SharedShape
Wraps the given shape as a shared shape.
sourcepub fn make_mut(&mut self) -> &mut (dyn Shape + 'static)
pub fn make_mut(&mut self) -> &mut (dyn Shape + 'static)
If this shape is shared, then the content of self is cloned into a unique instance,
and a mutable reference to that instance is returned.
sourcepub fn compound(
shapes: Vec<(Isometry<f32, Unit<Complex<f32>>, 2>, SharedShape)>,
) -> SharedShape
pub fn compound( shapes: Vec<(Isometry<f32, Unit<Complex<f32>>, 2>, SharedShape)>, ) -> SharedShape
Initialize a compound shape defined by its subshapes.
sourcepub fn ball(radius: f32) -> SharedShape
pub fn ball(radius: f32) -> SharedShape
Initialize a ball shape defined by its radius.
sourcepub fn halfspace(
outward_normal: Unit<Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>>,
) -> SharedShape
pub fn halfspace( outward_normal: Unit<Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>>, ) -> SharedShape
Initialize a plane shape defined by its outward normal.
sourcepub fn cuboid(hx: f32, hy: f32) -> SharedShape
pub fn cuboid(hx: f32, hy: f32) -> SharedShape
Initialize a cuboid shape defined by its half-extents.
sourcepub fn round_cuboid(hx: f32, hy: f32, border_radius: f32) -> SharedShape
pub fn round_cuboid(hx: f32, hy: f32, border_radius: f32) -> SharedShape
Initialize a round cuboid shape defined by its half-extents and border radius.
sourcepub fn capsule(
a: OPoint<f32, Const<2>>,
b: OPoint<f32, Const<2>>,
radius: f32,
) -> SharedShape
pub fn capsule( a: OPoint<f32, Const<2>>, b: OPoint<f32, Const<2>>, radius: f32, ) -> SharedShape
Initialize a capsule shape from its endpoints and radius.
sourcepub fn capsule_x(half_height: f32, radius: f32) -> SharedShape
pub fn capsule_x(half_height: f32, radius: f32) -> SharedShape
Initialize a capsule shape aligned with the x axis.
sourcepub fn capsule_y(half_height: f32, radius: f32) -> SharedShape
pub fn capsule_y(half_height: f32, radius: f32) -> SharedShape
Initialize a capsule shape aligned with the y axis.
sourcepub fn segment(
a: OPoint<f32, Const<2>>,
b: OPoint<f32, Const<2>>,
) -> SharedShape
pub fn segment( a: OPoint<f32, Const<2>>, b: OPoint<f32, Const<2>>, ) -> SharedShape
Initialize a segment shape from its endpoints.
sourcepub fn triangle(
a: OPoint<f32, Const<2>>,
b: OPoint<f32, Const<2>>,
c: OPoint<f32, Const<2>>,
) -> SharedShape
pub fn triangle( a: OPoint<f32, Const<2>>, b: OPoint<f32, Const<2>>, c: OPoint<f32, Const<2>>, ) -> SharedShape
Initializes a triangle shape.
sourcepub fn round_triangle(
a: OPoint<f32, Const<2>>,
b: OPoint<f32, Const<2>>,
c: OPoint<f32, Const<2>>,
border_radius: f32,
) -> SharedShape
pub fn round_triangle( a: OPoint<f32, Const<2>>, b: OPoint<f32, Const<2>>, c: OPoint<f32, Const<2>>, border_radius: f32, ) -> SharedShape
Initializes a triangle shape with round corners.
sourcepub fn polyline(
vertices: Vec<OPoint<f32, Const<2>>>,
indices: Option<Vec<[u32; 2]>>,
) -> SharedShape
pub fn polyline( vertices: Vec<OPoint<f32, Const<2>>>, indices: Option<Vec<[u32; 2]>>, ) -> SharedShape
Initializes a polyline shape defined by its vertex and index buffers.
If no index buffer is provided, the polyline is assumed to describe a line strip.
sourcepub fn trimesh(
vertices: Vec<OPoint<f32, Const<2>>>,
indices: Vec<[u32; 3]>,
) -> SharedShape
pub fn trimesh( vertices: Vec<OPoint<f32, Const<2>>>, indices: Vec<[u32; 3]>, ) -> SharedShape
Initializes a triangle mesh shape defined by its vertex and index buffers.
sourcepub fn trimesh_with_flags(
vertices: Vec<OPoint<f32, Const<2>>>,
indices: Vec<[u32; 3]>,
flags: TriMeshFlags,
) -> SharedShape
pub fn trimesh_with_flags( vertices: Vec<OPoint<f32, Const<2>>>, indices: Vec<[u32; 3]>, flags: TriMeshFlags, ) -> SharedShape
Initializes a triangle mesh shape defined by its vertex and index buffers and pre-processing flags.
sourcepub fn convex_decomposition(
vertices: &[OPoint<f32, Const<2>>],
indices: &[[u32; 2]],
) -> SharedShape
pub fn convex_decomposition( vertices: &[OPoint<f32, Const<2>>], indices: &[[u32; 2]], ) -> SharedShape
Initializes a compound shape obtained from the decomposition of the given trimesh (in 3D) or polyline (in 2D) into convex parts.
sourcepub fn round_convex_decomposition(
vertices: &[OPoint<f32, Const<2>>],
indices: &[[u32; 2]],
border_radius: f32,
) -> SharedShape
pub fn round_convex_decomposition( vertices: &[OPoint<f32, Const<2>>], indices: &[[u32; 2]], border_radius: f32, ) -> SharedShape
Initializes a compound shape obtained from the decomposition of the given trimesh (in 3D) or polyline (in 2D) into convex parts dilated with round corners.
sourcepub fn convex_decomposition_with_params(
vertices: &[OPoint<f32, Const<2>>],
indices: &[[u32; 2]],
params: &VHACDParameters,
) -> SharedShape
pub fn convex_decomposition_with_params( vertices: &[OPoint<f32, Const<2>>], indices: &[[u32; 2]], params: &VHACDParameters, ) -> SharedShape
Initializes a compound shape obtained from the decomposition of the given trimesh (in 3D) or polyline (in 2D) into convex parts.
sourcepub fn round_convex_decomposition_with_params(
vertices: &[OPoint<f32, Const<2>>],
indices: &[[u32; 2]],
params: &VHACDParameters,
border_radius: f32,
) -> SharedShape
pub fn round_convex_decomposition_with_params( vertices: &[OPoint<f32, Const<2>>], indices: &[[u32; 2]], params: &VHACDParameters, border_radius: f32, ) -> SharedShape
Initializes a compound shape obtained from the decomposition of the given trimesh (in 3D) or polyline (in 2D) into convex parts dilated with round corners.
sourcepub fn convex_hull(points: &[OPoint<f32, Const<2>>]) -> Option<SharedShape>
pub fn convex_hull(points: &[OPoint<f32, Const<2>>]) -> Option<SharedShape>
Creates a new shared shape that is the convex-hull of the given points.
sourcepub fn convex_polyline(
points: Vec<OPoint<f32, Const<2>>>,
) -> Option<SharedShape>
pub fn convex_polyline( points: Vec<OPoint<f32, Const<2>>>, ) -> Option<SharedShape>
Creates a new shared shape that is a convex polygon formed by the given set of points assumed to form a convex polyline (no convex-hull will be automatically computed).
sourcepub fn round_convex_hull(
points: &[OPoint<f32, Const<2>>],
border_radius: f32,
) -> Option<SharedShape>
pub fn round_convex_hull( points: &[OPoint<f32, Const<2>>], border_radius: f32, ) -> Option<SharedShape>
Creates a new shared shape with rounded corners that is the
convex-hull of the given points, dilated by border_radius.
sourcepub fn round_convex_polyline(
points: Vec<OPoint<f32, Const<2>>>,
border_radius: f32,
) -> Option<SharedShape>
pub fn round_convex_polyline( points: Vec<OPoint<f32, Const<2>>>, border_radius: f32, ) -> Option<SharedShape>
Creates a new shared shape with round corners that is a convex polygon formed by the given set of points assumed to form a convex polyline (no convex-hull will be automatically computed).
sourcepub fn heightfield(
heights: Matrix<f32, Dyn, Const<1>, VecStorage<f32, Dyn, Const<1>>>,
scale: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>,
) -> SharedShape
pub fn heightfield( heights: Matrix<f32, Dyn, Const<1>, VecStorage<f32, Dyn, Const<1>>>, scale: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>, ) -> SharedShape
Initializes a heightfield shape defined by its set of height and a scale factor along each coordinate axis.
Methods from Deref<Target = dyn Shape>
sourcepub fn is<__T>(&self) -> boolwhere
__T: Shape,
pub fn is<__T>(&self) -> boolwhere
__T: Shape,
Returns true if the trait object wraps an object of type __T.
sourcepub fn downcast_rc<__T>(self: Rc<dyn Shape>) -> Result<Rc<__T>, Rc<dyn Shape>>where
__T: Shape,
pub fn downcast_rc<__T>(self: Rc<dyn Shape>) -> Result<Rc<__T>, Rc<dyn Shape>>where
__T: Shape,
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
sourcepub fn downcast_ref<__T>(&self) -> Option<&__T>where
__T: Shape,
pub fn downcast_ref<__T>(&self) -> Option<&__T>where
__T: Shape,
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
sourcepub fn downcast_arc<__T>(
self: Arc<dyn Shape>,
) -> Result<Arc<__T>, Arc<dyn Shape>>
pub fn downcast_arc<__T>( self: Arc<dyn Shape>, ) -> Result<Arc<__T>, Arc<dyn Shape>>
Returns an Arc-ed object from an Arc-ed trait object if the underlying object is of
type __T. Returns the original Arc-ed trait if it isn’t.
sourcepub fn as_shape<T>(&self) -> Option<&T>where
T: Shape,
pub fn as_shape<T>(&self) -> Option<&T>where
T: Shape,
Converts this abstract shape to the given shape, if it is one.
sourcepub fn as_cuboid(&self) -> Option<&Cuboid>
pub fn as_cuboid(&self) -> Option<&Cuboid>
Converts this abstract shape to a cuboid, if it is one.
sourcepub fn as_halfspace(&self) -> Option<&HalfSpace>
pub fn as_halfspace(&self) -> Option<&HalfSpace>
Converts this abstract shape to a halfspace, if it is one.
sourcepub fn as_segment(&self) -> Option<&Segment>
pub fn as_segment(&self) -> Option<&Segment>
Converts this abstract shape to a segment, if it is one.
sourcepub fn as_capsule(&self) -> Option<&Capsule>
pub fn as_capsule(&self) -> Option<&Capsule>
Converts this abstract shape to a capsule, if it is one.
sourcepub fn as_triangle(&self) -> Option<&Triangle>
pub fn as_triangle(&self) -> Option<&Triangle>
Converts this abstract shape to a triangle, if it is one.
sourcepub fn as_compound(&self) -> Option<&Compound>
pub fn as_compound(&self) -> Option<&Compound>
Converts this abstract shape to a compound shape, if it is one.
sourcepub fn as_trimesh(&self) -> Option<&TriMesh>
pub fn as_trimesh(&self) -> Option<&TriMesh>
Converts this abstract shape to a triangle mesh, if it is one.
sourcepub fn as_polyline(&self) -> Option<&Polyline>
pub fn as_polyline(&self) -> Option<&Polyline>
Converts this abstract shape to a polyline, if it is one.
sourcepub fn as_heightfield(&self) -> Option<&HeightField>
pub fn as_heightfield(&self) -> Option<&HeightField>
Converts this abstract shape to a heightfield, if it is one.
sourcepub fn as_round_cuboid(&self) -> Option<&RoundShape<Cuboid>>
pub fn as_round_cuboid(&self) -> Option<&RoundShape<Cuboid>>
Converts this abstract shape to a round cuboid, if it is one.
sourcepub fn as_round_triangle(&self) -> Option<&RoundShape<Triangle>>
pub fn as_round_triangle(&self) -> Option<&RoundShape<Triangle>>
Converts this abstract shape to a round triangle, if it is one.
sourcepub fn as_convex_polygon(&self) -> Option<&ConvexPolygon>
pub fn as_convex_polygon(&self) -> Option<&ConvexPolygon>
Converts this abstract shape to a convex polygon, if it is one.
sourcepub fn as_round_convex_polygon(&self) -> Option<&RoundShape<ConvexPolygon>>
pub fn as_round_convex_polygon(&self) -> Option<&RoundShape<ConvexPolygon>>
Converts this abstract shape to a round convex polygon, if it is one.