Struct jumpy::core::physics::collisions::rapier::SolverContact
pub struct SolverContact {
pub(crate) contact_id: u8,
pub point: OPoint<f32, Const<2>>,
pub dist: f32,
pub friction: f32,
pub restitution: f32,
pub tangent_velocity: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>,
pub is_new: bool,
pub warmstart_impulse: f32,
pub warmstart_tangent_impulse: Matrix<f32, Const<1>, Const<1>, ArrayStorage<f32, 1, 1>>,
}Expand description
A contact seen by the constraints solver for computing forces.
Fields
contact_id: u8point: OPoint<f32, Const<2>>The contact point in world-space.
dist: f32The distance between the two original contacts points along the contact normal. If negative, this is measures the penetration depth.
friction: f32The effective friction coefficient at this contact point.
restitution: f32The effective restitution coefficient at this contact point.
tangent_velocity: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>The desired tangent relative velocity at the contact point.
This is set to zero by default. Set to a non-zero value to simulate, e.g., conveyor belts.
is_new: boolWhether or not this contact existed during the last timestep.
warmstart_impulse: f32Impulse used to warmstart the solve for the normal constraint.
warmstart_tangent_impulse: Matrix<f32, Const<1>, Const<1>, ArrayStorage<f32, 1, 1>>Impulse used to warmstart the solve for the friction constraints.
Implementations
impl SolverContact
impl SolverContact
pub fn is_bouncy(&self) -> bool
pub fn is_bouncy(&self) -> bool
Should we treat this contact as a bouncy contact?
If true, use Self::restitution.