pub struct LU<T, R, C>where
T: ComplexField,
R: DimMin<C>,
C: Dim,
DefaultAllocator: Allocator<T, R, C> + Allocator<(usize, usize), <R as DimMin<C>>::Output>,{
lu: Matrix<T, R, C, <DefaultAllocator as Allocator<T, R, C>>::Buffer>,
p: PermutationSequence<<R as DimMin<C>>::Output>,
}Expand description
LU decomposition with partial (row) pivoting.
Fields
lu: Matrix<T, R, C, <DefaultAllocator as Allocator<T, R, C>>::Buffer>p: PermutationSequence<<R as DimMin<C>>::Output>Implementations
sourceimpl<T, R, C> LU<T, R, C>where
T: ComplexField,
R: DimMin<C>,
C: Dim,
DefaultAllocator: Allocator<T, R, C> + Allocator<(usize, usize), <R as DimMin<C>>::Output>,
impl<T, R, C> LU<T, R, C>where
T: ComplexField,
R: DimMin<C>,
C: Dim,
DefaultAllocator: Allocator<T, R, C> + Allocator<(usize, usize), <R as DimMin<C>>::Output>,
sourcepub fn new(
matrix: Matrix<T, R, C, <DefaultAllocator as Allocator<T, R, C>>::Buffer>,
) -> LU<T, R, C>
pub fn new( matrix: Matrix<T, R, C, <DefaultAllocator as Allocator<T, R, C>>::Buffer>, ) -> LU<T, R, C>
Computes the LU decomposition with partial (row) pivoting of matrix.
sourcepub fn l(
&self,
) -> Matrix<T, R, <R as DimMin<C>>::Output, <DefaultAllocator as Allocator<T, R, <R as DimMin<C>>::Output>>::Buffer>
pub fn l( &self, ) -> Matrix<T, R, <R as DimMin<C>>::Output, <DefaultAllocator as Allocator<T, R, <R as DimMin<C>>::Output>>::Buffer>
The lower triangular matrix of this decomposition.
sourcepub fn l_unpack(
self,
) -> Matrix<T, R, <R as DimMin<C>>::Output, <DefaultAllocator as Allocator<T, R, <R as DimMin<C>>::Output>>::Buffer>
pub fn l_unpack( self, ) -> Matrix<T, R, <R as DimMin<C>>::Output, <DefaultAllocator as Allocator<T, R, <R as DimMin<C>>::Output>>::Buffer>
The lower triangular matrix of this decomposition.
sourcepub fn u(
&self,
) -> Matrix<T, <R as DimMin<C>>::Output, C, <DefaultAllocator as Allocator<T, <R as DimMin<C>>::Output, C>>::Buffer>
pub fn u( &self, ) -> Matrix<T, <R as DimMin<C>>::Output, C, <DefaultAllocator as Allocator<T, <R as DimMin<C>>::Output, C>>::Buffer>
The upper triangular matrix of this decomposition.
sourcepub fn p(&self) -> &PermutationSequence<<R as DimMin<C>>::Output>
pub fn p(&self) -> &PermutationSequence<<R as DimMin<C>>::Output>
The row permutations of this decomposition.
sourcepub fn unpack(
self,
) -> (PermutationSequence<<R as DimMin<C>>::Output>, Matrix<T, R, <R as DimMin<C>>::Output, <DefaultAllocator as Allocator<T, R, <R as DimMin<C>>::Output>>::Buffer>, Matrix<T, <R as DimMin<C>>::Output, C, <DefaultAllocator as Allocator<T, <R as DimMin<C>>::Output, C>>::Buffer>)where
DefaultAllocator: Allocator<T, R, <R as DimMin<C>>::Output> + Allocator<T, <R as DimMin<C>>::Output, C> + Reallocator<T, R, C, R, <R as DimMin<C>>::Output>,
pub fn unpack(
self,
) -> (PermutationSequence<<R as DimMin<C>>::Output>, Matrix<T, R, <R as DimMin<C>>::Output, <DefaultAllocator as Allocator<T, R, <R as DimMin<C>>::Output>>::Buffer>, Matrix<T, <R as DimMin<C>>::Output, C, <DefaultAllocator as Allocator<T, <R as DimMin<C>>::Output, C>>::Buffer>)where
DefaultAllocator: Allocator<T, R, <R as DimMin<C>>::Output> + Allocator<T, <R as DimMin<C>>::Output, C> + Reallocator<T, R, C, R, <R as DimMin<C>>::Output>,
The row permutations and two triangular matrices of this decomposition: (P, L, U).
sourceimpl<T, D> LU<T, D, D>where
T: ComplexField,
D: DimMin<D, Output = D>,
DefaultAllocator: Allocator<T, D, D> + Allocator<(usize, usize), D>,
impl<T, D> LU<T, D, D>where
T: ComplexField,
D: DimMin<D, Output = D>,
DefaultAllocator: Allocator<T, D, D> + Allocator<(usize, usize), D>,
sourcepub fn solve<R2, C2, S2>(
&self,
b: &Matrix<T, R2, C2, S2>,
) -> Option<Matrix<T, R2, C2, <DefaultAllocator as Allocator<T, R2, C2>>::Buffer>>where
R2: Dim,
C2: Dim,
S2: Storage<T, R2, C2>,
ShapeConstraint: SameNumberOfRows<R2, D>,
DefaultAllocator: Allocator<T, R2, C2>,
pub fn solve<R2, C2, S2>(
&self,
b: &Matrix<T, R2, C2, S2>,
) -> Option<Matrix<T, R2, C2, <DefaultAllocator as Allocator<T, R2, C2>>::Buffer>>where
R2: Dim,
C2: Dim,
S2: Storage<T, R2, C2>,
ShapeConstraint: SameNumberOfRows<R2, D>,
DefaultAllocator: Allocator<T, R2, C2>,
Solves the linear system self * x = b, where x is the unknown to be determined.
Returns None if self is not invertible.
sourcepub fn solve_mut<R2, C2, S2>(&self, b: &mut Matrix<T, R2, C2, S2>) -> bool
pub fn solve_mut<R2, C2, S2>(&self, b: &mut Matrix<T, R2, C2, S2>) -> bool
Solves the linear system self * x = b, where x is the unknown to be determined.
If the decomposed matrix is not invertible, this returns false and its input b may
be overwritten with garbage.
sourcepub fn try_inverse(
&self,
) -> Option<Matrix<T, D, D, <DefaultAllocator as Allocator<T, D, D>>::Buffer>>
pub fn try_inverse( &self, ) -> Option<Matrix<T, D, D, <DefaultAllocator as Allocator<T, D, D>>::Buffer>>
Computes the inverse of the decomposed matrix.
Returns None if the matrix is not invertible.
sourcepub fn try_inverse_to<S2>(&self, out: &mut Matrix<T, D, D, S2>) -> boolwhere
S2: StorageMut<T, D, D>,
pub fn try_inverse_to<S2>(&self, out: &mut Matrix<T, D, D, S2>) -> boolwhere
S2: StorageMut<T, D, D>,
Computes the inverse of the decomposed matrix and outputs the result to out.
If the decomposed matrix is not invertible, this returns false and out may be
overwritten with garbage.
sourcepub fn determinant(&self) -> T
pub fn determinant(&self) -> T
Computes the determinant of the decomposed matrix.
sourcepub fn is_invertible(&self) -> bool
pub fn is_invertible(&self) -> bool
Indicates if the decomposed matrix is invertible.