Struct jumpy::core::physics::rapier::DebugRenderPipeline
pub struct DebugRenderPipeline {
instances: HashMap<TypeId, Vec<OPoint<f32, Const<2>>>>,
pub style: DebugRenderStyle,
pub mode: DebugRenderMode,
}Expand description
Pipeline responsible for rendering the state of the physics engine for debugging purpose.
Fields
instances: HashMap<TypeId, Vec<OPoint<f32, Const<2>>>>style: DebugRenderStyleThe style used to compute the line colors for each element to render.
mode: DebugRenderModeFlags controlling what part of the physics engine need to be rendered.
Implementations
impl DebugRenderPipeline
impl DebugRenderPipeline
pub fn new(
style: DebugRenderStyle,
mode: DebugRenderMode,
) -> DebugRenderPipeline
pub fn new( style: DebugRenderStyle, mode: DebugRenderMode, ) -> DebugRenderPipeline
Creates a new debug-render pipeline from a given style and flags.
pub fn render_all(style: DebugRenderStyle) -> DebugRenderPipeline
pub fn render_all(style: DebugRenderStyle) -> DebugRenderPipeline
Creates a new debug-render pipeline that renders everything it can from the physics state.
pub fn render(
&mut self,
backend: &mut impl DebugRenderBackend,
bodies: &RigidBodySet,
colliders: &ColliderSet,
impulse_joints: &ImpulseJointSet,
multibody_joints: &MultibodyJointSet,
narrow_phase: &NarrowPhase,
)
pub fn render( &mut self, backend: &mut impl DebugRenderBackend, bodies: &RigidBodySet, colliders: &ColliderSet, impulse_joints: &ImpulseJointSet, multibody_joints: &MultibodyJointSet, narrow_phase: &NarrowPhase, )
Render the scene.
pub fn render_contacts(
&mut self,
backend: &mut impl DebugRenderBackend,
colliders: &ColliderSet,
narrow_phase: &NarrowPhase,
)
pub fn render_contacts( &mut self, backend: &mut impl DebugRenderBackend, colliders: &ColliderSet, narrow_phase: &NarrowPhase, )
Render contact.
pub fn render_joints(
&mut self,
backend: &mut impl DebugRenderBackend,
bodies: &RigidBodySet,
impulse_joints: &ImpulseJointSet,
multibody_joints: &MultibodyJointSet,
)
pub fn render_joints( &mut self, backend: &mut impl DebugRenderBackend, bodies: &RigidBodySet, impulse_joints: &ImpulseJointSet, multibody_joints: &MultibodyJointSet, )
Render only the joints from the scene.
pub fn render_rigid_bodies(
&mut self,
backend: &mut impl DebugRenderBackend,
bodies: &RigidBodySet,
)
pub fn render_rigid_bodies( &mut self, backend: &mut impl DebugRenderBackend, bodies: &RigidBodySet, )
Render only the rigid-bodies from the scene.
pub fn render_colliders(
&mut self,
backend: &mut impl DebugRenderBackend,
bodies: &RigidBodySet,
colliders: &ColliderSet,
)
pub fn render_colliders( &mut self, backend: &mut impl DebugRenderBackend, bodies: &RigidBodySet, colliders: &ColliderSet, )
Render only the colliders from the scene.