Struct jumpy::core::physics::rapier::GenericJointBuilder
pub struct GenericJointBuilder(pub GenericJoint);Expand description
Create generic joints using the builder pattern.
Tuple Fields
0: GenericJointImplementations
impl GenericJointBuilder
impl GenericJointBuilder
pub fn new(locked_axes: JointAxesMask) -> GenericJointBuilder
pub fn new(locked_axes: JointAxesMask) -> GenericJointBuilder
Creates a new generic joint builder.
pub fn locked_axes(self, axes: JointAxesMask) -> GenericJointBuilder
pub fn locked_axes(self, axes: JointAxesMask) -> GenericJointBuilder
Sets the degrees of freedom locked by the joint.
pub fn contacts_enabled(self, enabled: bool) -> GenericJointBuilder
pub fn contacts_enabled(self, enabled: bool) -> GenericJointBuilder
Sets whether contacts between the attached rigid-bodies are enabled.
pub fn local_frame1(
self,
local_frame: Isometry<f32, Unit<Complex<f32>>, 2>,
) -> GenericJointBuilder
pub fn local_frame1( self, local_frame: Isometry<f32, Unit<Complex<f32>>, 2>, ) -> GenericJointBuilder
Sets the joint’s frame, expressed in the first rigid-body’s local-space.
pub fn local_frame2(
self,
local_frame: Isometry<f32, Unit<Complex<f32>>, 2>,
) -> GenericJointBuilder
pub fn local_frame2( self, local_frame: Isometry<f32, Unit<Complex<f32>>, 2>, ) -> GenericJointBuilder
Sets the joint’s frame, expressed in the second rigid-body’s local-space.
pub fn local_axis1(
self,
local_axis: Unit<Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>>,
) -> GenericJointBuilder
pub fn local_axis1( self, local_axis: Unit<Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>>, ) -> GenericJointBuilder
Sets the principal (local X) axis of this joint, expressed in the first rigid-body’s local-space.
pub fn local_axis2(
self,
local_axis: Unit<Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>>,
) -> GenericJointBuilder
pub fn local_axis2( self, local_axis: Unit<Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>>, ) -> GenericJointBuilder
Sets the principal (local X) axis of this joint, expressed in the second rigid-body’s local-space.
pub fn local_anchor1(
self,
anchor1: OPoint<f32, Const<2>>,
) -> GenericJointBuilder
pub fn local_anchor1( self, anchor1: OPoint<f32, Const<2>>, ) -> GenericJointBuilder
Sets the anchor of this joint, expressed in the first rigid-body’s local-space.
pub fn local_anchor2(
self,
anchor2: OPoint<f32, Const<2>>,
) -> GenericJointBuilder
pub fn local_anchor2( self, anchor2: OPoint<f32, Const<2>>, ) -> GenericJointBuilder
Sets the anchor of this joint, expressed in the second rigid-body’s local-space.
pub fn limits(self, axis: JointAxis, limits: [f32; 2]) -> GenericJointBuilder
pub fn limits(self, axis: JointAxis, limits: [f32; 2]) -> GenericJointBuilder
Sets the joint limits along the specified axis.
pub fn coupled_axes(self, axes: JointAxesMask) -> GenericJointBuilder
pub fn coupled_axes(self, axes: JointAxesMask) -> GenericJointBuilder
Sets the coupled degrees of freedom for this joint’s limits and motor.
pub fn motor_model(
self,
axis: JointAxis,
model: MotorModel,
) -> GenericJointBuilder
pub fn motor_model( self, axis: JointAxis, model: MotorModel, ) -> GenericJointBuilder
Set the spring-like model used by the motor to reach the desired target velocity and position.
pub fn motor_velocity(
self,
axis: JointAxis,
target_vel: f32,
factor: f32,
) -> GenericJointBuilder
pub fn motor_velocity( self, axis: JointAxis, target_vel: f32, factor: f32, ) -> GenericJointBuilder
Sets the target velocity this motor needs to reach.
pub fn motor_position(
self,
axis: JointAxis,
target_pos: f32,
stiffness: f32,
damping: f32,
) -> GenericJointBuilder
pub fn motor_position( self, axis: JointAxis, target_pos: f32, stiffness: f32, damping: f32, ) -> GenericJointBuilder
Sets the target angle this motor needs to reach.
pub fn set_motor(
self,
axis: JointAxis,
target_pos: f32,
target_vel: f32,
stiffness: f32,
damping: f32,
) -> GenericJointBuilder
pub fn set_motor( self, axis: JointAxis, target_pos: f32, target_vel: f32, stiffness: f32, damping: f32, ) -> GenericJointBuilder
Configure both the target angle and target velocity of the motor.
pub fn motor_max_force(
self,
axis: JointAxis,
max_force: f32,
) -> GenericJointBuilder
pub fn motor_max_force( self, axis: JointAxis, max_force: f32, ) -> GenericJointBuilder
Sets the maximum force the motor can deliver along the specified axis.
pub fn user_data(self, data: u128) -> GenericJointBuilder
pub fn user_data(self, data: u128) -> GenericJointBuilder
An arbitrary user-defined 128-bit integer associated to the joints built by this builder.
pub fn build(self) -> GenericJoint
pub fn build(self) -> GenericJoint
Builds the generic joint.