Struct jumpy::core::physics::rapier::LockedAxes
pub struct LockedAxes {
bits: u8,
}Expand description
Flags affecting the behavior of the constraints solver for a given contact manifold.
Fields
bits: u8Implementations
impl LockedAxes
impl LockedAxes
pub const TRANSLATION_LOCKED_X: LockedAxes = _
pub const TRANSLATION_LOCKED_X: LockedAxes = _
Flag indicating that the rigid-body cannot translate along the X axis.
pub const TRANSLATION_LOCKED_Y: LockedAxes = _
pub const TRANSLATION_LOCKED_Y: LockedAxes = _
Flag indicating that the rigid-body cannot translate along the Y axis.
pub const TRANSLATION_LOCKED_Z: LockedAxes = _
pub const TRANSLATION_LOCKED_Z: LockedAxes = _
Flag indicating that the rigid-body cannot translate along the Z axis.
pub const TRANSLATION_LOCKED: LockedAxes = _
pub const TRANSLATION_LOCKED: LockedAxes = _
Flag indicating that the rigid-body cannot translate along any direction.
pub const ROTATION_LOCKED_X: LockedAxes = _
pub const ROTATION_LOCKED_X: LockedAxes = _
Flag indicating that the rigid-body cannot rotate along the X axis.
pub const ROTATION_LOCKED_Y: LockedAxes = _
pub const ROTATION_LOCKED_Y: LockedAxes = _
Flag indicating that the rigid-body cannot rotate along the Y axis.
pub const ROTATION_LOCKED_Z: LockedAxes = _
pub const ROTATION_LOCKED_Z: LockedAxes = _
Flag indicating that the rigid-body cannot rotate along the Z axis.
pub const ROTATION_LOCKED: LockedAxes = _
pub const ROTATION_LOCKED: LockedAxes = _
Combination of flags indicating that the rigid-body cannot rotate along any axis.
pub const fn empty() -> LockedAxes
pub const fn empty() -> LockedAxes
Returns an empty set of flags.
pub const fn all() -> LockedAxes
pub const fn all() -> LockedAxes
Returns the set containing all flags.
pub const fn from_bits(bits: u8) -> Option<LockedAxes>
pub const fn from_bits(bits: u8) -> Option<LockedAxes>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u8) -> LockedAxes
pub const fn from_bits_truncate(bits: u8) -> LockedAxes
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: u8) -> LockedAxes
pub const unsafe fn from_bits_unchecked(bits: u8) -> LockedAxes
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
pub const fn intersects(&self, other: LockedAxes) -> bool
pub const fn intersects(&self, other: LockedAxes) -> bool
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: LockedAxes) -> bool
pub const fn contains(&self, other: LockedAxes) -> bool
Returns true if all of the flags in other are contained within self.
pub fn insert(&mut self, other: LockedAxes)
pub fn insert(&mut self, other: LockedAxes)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: LockedAxes)
pub fn remove(&mut self, other: LockedAxes)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: LockedAxes)
pub fn toggle(&mut self, other: LockedAxes)
Toggles the specified flags in-place.
pub fn set(&mut self, other: LockedAxes, value: bool)
pub fn set(&mut self, other: LockedAxes, value: bool)
Inserts or removes the specified flags depending on the passed value.
pub const fn intersection(self, other: LockedAxes) -> LockedAxes
pub const fn intersection(self, other: LockedAxes) -> LockedAxes
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
pub const fn union(self, other: LockedAxes) -> LockedAxes
pub const fn union(self, other: LockedAxes) -> LockedAxes
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
pub const fn difference(self, other: LockedAxes) -> LockedAxes
pub const fn difference(self, other: LockedAxes) -> LockedAxes
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
pub const fn symmetric_difference(self, other: LockedAxes) -> LockedAxes
pub const fn symmetric_difference(self, other: LockedAxes) -> LockedAxes
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
pub const fn complement(self) -> LockedAxes
pub const fn complement(self) -> LockedAxes
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.