#[repr(C)]pub struct TriMesh {
qbvh: Qbvh<u32>,
vertices: Vec<OPoint<f32, Const<2>>>,
indices: Vec<[u32; 3]>,
topology: Option<TriMeshTopology>,
connected_components: Option<TriMeshConnectedComponents>,
flags: TriMeshFlags,
}Expand description
A triangle mesh.
Fields
qbvh: Qbvh<u32>vertices: Vec<OPoint<f32, Const<2>>>indices: Vec<[u32; 3]>topology: Option<TriMeshTopology>connected_components: Option<TriMeshConnectedComponents>flags: TriMeshFlagsImplementations
sourceimpl TriMesh
impl TriMesh
sourcepub fn bounding_sphere(
&self,
pos: &Isometry<f32, Unit<Complex<f32>>, 2>,
) -> BoundingSphere
pub fn bounding_sphere( &self, pos: &Isometry<f32, Unit<Complex<f32>>, 2>, ) -> BoundingSphere
Computes the world-space bounding sphere of this triangle mesh, transformed by pos.
sourcepub fn local_bounding_sphere(&self) -> BoundingSphere
pub fn local_bounding_sphere(&self) -> BoundingSphere
Computes the local-space bounding sphere of this triangle mesh.
sourceimpl TriMesh
impl TriMesh
sourcepub fn new(
vertices: Vec<OPoint<f32, Const<2>>>,
indices: Vec<[u32; 3]>,
) -> TriMesh
pub fn new( vertices: Vec<OPoint<f32, Const<2>>>, indices: Vec<[u32; 3]>, ) -> TriMesh
Creates a new triangle mesh from a vertex buffer and an index buffer.
sourcepub fn with_flags(
vertices: Vec<OPoint<f32, Const<2>>>,
indices: Vec<[u32; 3]>,
flags: TriMeshFlags,
) -> TriMesh
pub fn with_flags( vertices: Vec<OPoint<f32, Const<2>>>, indices: Vec<[u32; 3]>, flags: TriMeshFlags, ) -> TriMesh
Creates a new triangle mesh from a vertex buffer and an index buffer, and flags controlling optional properties.
sourcepub fn set_flags(&mut self, flags: TriMeshFlags) -> Result<(), TopologyError>
pub fn set_flags(&mut self, flags: TriMeshFlags) -> Result<(), TopologyError>
Sets the flags of this triangle mesh, controlling its optional associated data.
sourcepub fn transform_vertices(
&mut self,
transform: &Isometry<f32, Unit<Complex<f32>>, 2>,
)
pub fn transform_vertices( &mut self, transform: &Isometry<f32, Unit<Complex<f32>>, 2>, )
Transforms in-place the vertices of this triangle mesh.
sourcepub fn scaled(
self,
scale: &Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>,
) -> TriMesh
pub fn scaled( self, scale: &Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>, ) -> TriMesh
Returns a scaled version of this triangle mesh.
sourcepub fn from_polygon(vertices: Vec<OPoint<f32, Const<2>>>) -> Option<TriMesh>
pub fn from_polygon(vertices: Vec<OPoint<f32, Const<2>>>) -> Option<TriMesh>
Create a TriMesh from a set of points assumed to describe a counter-clockwise non-convex polygon.
This operation may fail if the input polygon is invalid, e.g. it is non-simple or has zero surface area.
sourcepub fn flat_indices(&self) -> &[u32]
pub fn flat_indices(&self) -> &[u32]
A flat view of the index buffer of this mesh.
sourcepub fn triangles(&self) -> impl ExactSizeIterator
pub fn triangles(&self) -> impl ExactSizeIterator
An iterator through all the triangles of this mesh.
sourceimpl TriMesh
impl TriMesh
sourcepub fn flags(&self) -> TriMeshFlags
pub fn flags(&self) -> TriMeshFlags
The flags of this triangle mesh.
sourcepub fn aabb(&self, pos: &Isometry<f32, Unit<Complex<f32>>, 2>) -> Aabb
pub fn aabb(&self, pos: &Isometry<f32, Unit<Complex<f32>>, 2>) -> Aabb
Compute the axis-aligned bounding box of this triangle mesh.
sourcepub fn local_aabb(&self) -> &Aabb
pub fn local_aabb(&self) -> &Aabb
Gets the local axis-aligned bounding box of this triangle mesh.
sourcepub fn num_triangles(&self) -> usize
pub fn num_triangles(&self) -> usize
The number of triangles forming this mesh.
sourcepub fn is_backface(&self, feature: FeatureId) -> bool
pub fn is_backface(&self, feature: FeatureId) -> bool
Does the given feature ID identify a backface of this trimesh?
sourcepub fn topology(&self) -> Option<&TriMeshTopology>
pub fn topology(&self) -> Option<&TriMeshTopology>
Returns the topology information of this trimesh, if it has been computed.
sourcepub fn connected_components(&self) -> Option<&TriMeshConnectedComponents>
pub fn connected_components(&self) -> Option<&TriMeshConnectedComponents>
Returns the connected-component information of this trimesh, if it has been computed.