Struct jumpy::input::DensePlayerControl
source · #[repr(transparent)]pub struct DensePlayerControl(pub u32);Expand description
A player’s controller inputs densely packed into a single u32.
This is used when sending player inputs across the network.
Tuple Fields
0: u32Implementations
sourceimpl DensePlayerControl
impl DensePlayerControl
pub fn jump_pressed(&self) -> bool
pub fn shoot_pressed(&self) -> bool
pub fn grab_pressed(&self) -> bool
pub fn slide_pressed(&self) -> bool
pub fn ragdoll_pressed(&self) -> bool
pub fn move_direction(&self) -> DenseMoveDirection
pub fn set_jump_pressed(&mut self, value: bool)
pub fn set_shoot_pressed(&mut self, value: bool)
pub fn set_grab_pressed(&mut self, value: bool)
pub fn set_slide_pressed(&mut self, value: bool)
pub fn set_ragdoll_pressed(&mut self, value: bool)
pub fn set_move_direction(&mut self, value: DenseMoveDirection)