Struct jumpy::prelude::bones_schema::prelude::SchemaVec
pub struct SchemaVec {
buffer: ResizableAlloc,
len: usize,
schema: &'static Schema,
}Expand description
A type-erased Vec-like collection that for items with the same [Schema].
Fields
buffer: ResizableAlloclen: usizeschema: &'static SchemaImplementations
impl SchemaVec
impl SchemaVec
pub fn new(schema: &'static Schema) -> SchemaVec
pub fn new(schema: &'static Schema) -> SchemaVec
Initialize an empty SchemaVec for items with the given schema.
pub fn try_push<T>(&mut self, item: T) -> Result<(), SchemaMismatchError>where
T: HasSchema,
pub fn try_push<T>(&mut self, item: T) -> Result<(), SchemaMismatchError>where
T: HasSchema,
pub fn try_push_box(
&mut self,
item: SchemaBox,
) -> Result<(), SchemaMismatchError>
pub fn try_push_box( &mut self, item: SchemaBox, ) -> Result<(), SchemaMismatchError>
Push the item into the end of the vector.
pub fn try_pop<T>(&mut self) -> Result<Option<T>, SchemaMismatchError>where
T: HasSchema,
pub fn try_pop<T>(&mut self) -> Result<Option<T>, SchemaMismatchError>where
T: HasSchema,
pub fn try_get_mut<T>(
&mut self,
idx: usize,
) -> Result<Option<&mut T>, SchemaMismatchError>where
T: HasSchema,
pub fn try_get_mut<T>(
&mut self,
idx: usize,
) -> Result<Option<&mut T>, SchemaMismatchError>where
T: HasSchema,
pub fn get_ref_mut(&mut self, idx: usize) -> Option<SchemaRefMut<'_>>
pub fn get_ref_mut(&mut self, idx: usize) -> Option<SchemaRefMut<'_>>
Get an item with the given index.
pub fn iter(&self) -> SchemaVecIter<'_> ⓘ
pub fn iter(&self) -> SchemaVecIter<'_> ⓘ
Iterate over values in the vec
pub fn iter_mut(&mut self) -> SchemaVecIterMut<'_> ⓘ
pub fn iter_mut(&mut self) -> SchemaVecIterMut<'_> ⓘ
Iterate mutably over values in the vec
pub fn try_into_svec<T>(self) -> Result<SVec<T>, SchemaMismatchError>where
T: HasSchema,
pub fn try_into_svec<T>(self) -> Result<SVec<T>, SchemaMismatchError>where
T: HasSchema,
pub fn remove(&mut self, index: usize) -> SchemaBox
pub fn remove(&mut self, index: usize) -> SchemaBox
Remove and return the element at position index within the vector,
shifting all elements after it to the left.
Panics
Panics if index is out of bounds.
pub fn clear(&mut self)
pub fn clear(&mut self)
Clears the vector, removing all values.