Struct jumpy::prelude::egui::containers::Area
pub struct Area {
pub(crate) id: Id,
movable: bool,
interactable: bool,
enabled: bool,
constrain: bool,
constrain_rect: Option<Rect>,
order: Order,
default_pos: Option<Pos2>,
pivot: Align2,
anchor: Option<(Align2, Vec2)>,
new_pos: Option<Pos2>,
}Expand description
An area on the screen that can be moved by dragging.
This forms the base of the Window container.
egui::Area::new("my_area")
.fixed_pos(egui::pos2(32.0, 32.0))
.show(ctx, |ui| {
ui.label("Floating text!");
});The previous rectangle used by this area can be obtained through crate::Memory::area_rect().
Fields
id: Idmovable: boolinteractable: boolenabled: boolconstrain: boolconstrain_rect: Option<Rect>order: Orderdefault_pos: Option<Pos2>pivot: Align2anchor: Option<(Align2, Vec2)>new_pos: Option<Pos2>Implementations
impl Area
impl Area
pub fn new(id: impl Into<Id>) -> Area
pub fn id(self, id: Id) -> Area
pub fn layer(&self) -> LayerId
pub fn enabled(self, enabled: bool) -> Area
pub fn enabled(self, enabled: bool) -> Area
If false, no content responds to click
and widgets will be shown grayed out.
You won’t be able to move the window.
Default: true.
pub fn is_enabled(&self) -> bool
pub fn is_movable(&self) -> bool
pub fn interactable(self, interactable: bool) -> Area
pub fn interactable(self, interactable: bool) -> Area
If false, clicks goes straight through to what is behind us. Good for tooltips etc.
pub fn order(self, order: Order) -> Area
pub fn order(self, order: Order) -> Area
order(Order::Foreground) for an Area that should always be on top
pub fn default_pos(self, default_pos: impl Into<Pos2>) -> Area
pub fn fixed_pos(self, fixed_pos: impl Into<Pos2>) -> Area
pub fn fixed_pos(self, fixed_pos: impl Into<Pos2>) -> Area
Positions the window and prevents it from being moved
pub fn constrain_to(self, constrain_rect: Rect) -> Area
pub fn constrain_to(self, constrain_rect: Rect) -> Area
Constraint the movement of the window to the given rectangle.
For instance: .constrain_to(ctx.screen_rect()).
pub fn drag_bounds(self, constrain_rect: Rect) -> Area
constrain_to insteadpub fn pivot(self, pivot: Align2) -> Area
pub fn pivot(self, pivot: Align2) -> Area
Where the “root” of the area is.
For instance, if you set this to Align2::RIGHT_TOP
then Self::fixed_pos will set the position of the right-top
corner of the area.
Default: Align2::LEFT_TOP.
pub fn current_pos(self, current_pos: impl Into<Pos2>) -> Area
pub fn current_pos(self, current_pos: impl Into<Pos2>) -> Area
Positions the window but you can still move it.
pub fn anchor(self, align: Align2, offset: impl Into<Vec2>) -> Area
pub fn anchor(self, align: Align2, offset: impl Into<Vec2>) -> Area
Set anchor and distance.
An anchor of Align2::RIGHT_TOP means “put the right-top corner of the window
in the right-top corner of the screen”.
The offset is added to the position, so e.g. an offset of [-5.0, 5.0]
would move the window left and down from the given anchor.
Anchoring also makes the window immovable.
It is an error to set both an anchor and a position.