Enum jumpy::prelude::egui::TouchPhase
pub enum TouchPhase {
Start,
Move,
End,
Cancel,
}Expand description
In what phase a touch event is in.
Variants
Start
User just placed a touch point on the touch surface
Move
User moves a touch point along the surface. This event is also sent when any attributes (position, force, …) of the touch point change.
End
User lifted the finger or pen from the surface, or slid off the edge of the surface
Cancel
Touch operation has been disrupted by something (various reasons are possible, maybe a pop-up alert or any other kind of interruption which may not have been intended by the user)