#[repr(C)]pub struct Color32(pub(crate) [u8; 4]);Expand description
This format is used for space-efficient color representation (32 bits).
Instead of manipulating this directly it is often better
to first convert it to either Rgba or crate::Hsva.
Internally this uses 0-255 gamma space sRGBA color with premultiplied alpha.
Alpha channel is in linear space.
Tuple Fields
0: [u8; 4]Implementations
impl Color32
impl Color32
pub const TRANSPARENT: Color32 = _
pub const BLACK: Color32 = _
pub const DARK_GRAY: Color32 = _
pub const GRAY: Color32 = _
pub const LIGHT_GRAY: Color32 = _
pub const WHITE: Color32 = _
pub const BROWN: Color32 = _
pub const DARK_RED: Color32 = _
pub const RED: Color32 = _
pub const LIGHT_RED: Color32 = _
pub const YELLOW: Color32 = _
pub const LIGHT_YELLOW: Color32 = _
pub const KHAKI: Color32 = _
pub const DARK_GREEN: Color32 = _
pub const GREEN: Color32 = _
pub const LIGHT_GREEN: Color32 = _
pub const DARK_BLUE: Color32 = _
pub const BLUE: Color32 = _
pub const LIGHT_BLUE: Color32 = _
pub const GOLD: Color32 = _
pub const DEBUG_COLOR: Color32 = _
pub const TEMPORARY_COLOR: Color32 = _
pub const TEMPORARY_COLOR: Color32 = _
An ugly color that is planned to be replaced before making it to the screen.
pub const fn from_rgb(r: u8, g: u8, b: u8) -> Color32
pub const fn from_rgb_additive(r: u8, g: u8, b: u8) -> Color32
pub const fn from_rgba_premultiplied(r: u8, g: u8, b: u8, a: u8) -> Color32
pub const fn from_rgba_premultiplied(r: u8, g: u8, b: u8, a: u8) -> Color32
From sRGBA with premultiplied alpha.
pub fn from_rgba_unmultiplied(r: u8, g: u8, b: u8, a: u8) -> Color32
pub fn from_rgba_unmultiplied(r: u8, g: u8, b: u8, a: u8) -> Color32
From sRGBA WITHOUT premultiplied alpha.
pub const fn from_gray(l: u8) -> Color32
pub const fn from_black_alpha(a: u8) -> Color32
pub fn from_white_alpha(a: u8) -> Color32
pub const fn from_additive_luminance(l: u8) -> Color32
pub const fn is_opaque(&self) -> bool
pub const fn r(&self) -> u8
pub const fn g(&self) -> u8
pub const fn b(&self) -> u8
pub const fn a(&self) -> u8
pub fn is_additive(self) -> bool
pub fn is_additive(self) -> bool
Is the alpha=0 ?
pub fn to_srgba_unmultiplied(&self) -> [u8; 4]
pub fn gamma_multiply(self, factor: f32) -> Color32
pub fn gamma_multiply(self, factor: f32) -> Color32
Multiply with 0.5 to make color half as opaque, perceptually.
Fast multiplication in gamma-space.
This is perceptually even, and faster that Self::linear_multiply.
pub fn linear_multiply(self, factor: f32) -> Color32
pub fn linear_multiply(self, factor: f32) -> Color32
Multiply with 0.5 to make color half as opaque in linear space.
This is using linear space, which is not perceptually even.
You may want to use Self::gamma_multiply instead.
pub fn to_normalized_gamma_f32(self) -> [f32; 4]
pub fn to_normalized_gamma_f32(self) -> [f32; 4]
Converts to floating point values in the range 0-1 without any gamma space conversion.
Use this with great care! In almost all cases, you want to convert to crate::Rgba instead
in order to obtain linear space color values.