Struct jumpy::prelude::egui::output::FullOutput
pub struct FullOutput {
pub platform_output: PlatformOutput,
pub repaint_after: Duration,
pub textures_delta: TexturesDelta,
pub shapes: Vec<ClippedShape>,
}Expand description
What egui emits each frame from crate::Context::run.
The backend should use this.
Fields
platform_output: PlatformOutputNon-rendering related output.
repaint_after: DurationIf Duration::is_zero(), egui is requesting immediate repaint (i.e. on the next frame).
This happens for instance when there is an animation, or if a user has called Context::request_repaint().
If Duration is greater than zero, egui wants to be repainted at or before the specified
duration elapses. when in reactive mode, egui spends forever waiting for input and only then,
will it repaint itself. this can be used to make sure that backend will only wait for a
specified amount of time, and repaint egui without any new input.
textures_delta: TexturesDeltaTexture changes since last frame (including the font texture).
The backend needs to apply crate::TexturesDelta::set before painting,
and free any texture in crate::TexturesDelta::free after painting.
shapes: Vec<ClippedShape>What to paint.
You can use crate::Context::tessellate to turn this into triangles.
Implementations
impl FullOutput
impl FullOutput
pub fn append(&mut self, newer: FullOutput)
pub fn append(&mut self, newer: FullOutput)
Add on new output.