pub struct ClockTime {
pub clock: ClockId,
pub ticks: u64,
pub fraction: f64,
}Expand description
An instant in time associated with a clock.
ClockTimes implement PartialOrd. They can be compared as long
as both times are associated with the same clock. If the clocks are
different, a.cmp(b) will return None.
Fields
clock: ClockIdThe clock this time is associated with.
ticks: u64The elapsed time in whole ticks.
fraction: f64The amount of time since the last tick as a fraction of a tick.
This will always be in the range of 0.0 (inclusive) to 1.0 (exclusive).
Implementations
impl ClockTime
impl ClockTime
pub fn from_ticks_u64(clock: impl Into<ClockId>, ticks: u64) -> ClockTime
pub fn from_ticks_u64(clock: impl Into<ClockId>, ticks: u64) -> ClockTime
Creates a ClockTime for a clock with the specified number of
whole ticks.
Example
use kira::{
manager::{AudioManager, backend::DefaultBackend, AudioManagerSettings},
clock::{ClockSpeed, ClockTime},
};
let mut manager = AudioManager::<DefaultBackend>::new(AudioManagerSettings::default())?;
let clock = manager.add_clock(ClockSpeed::TicksPerMinute(120.0))?;
assert_eq!(
ClockTime::from_ticks_u64(&clock, 3),
ClockTime {
clock: clock.id(),
ticks: 3,
fraction: 0.0,
},
);pub fn from_ticks_f64(clock: impl Into<ClockId>, ticks: f64) -> ClockTime
pub fn from_ticks_f64(clock: impl Into<ClockId>, ticks: f64) -> ClockTime
Creates a ClockTime for a clock with the specified number of
ticks.
Example
use kira::{
manager::{AudioManager, backend::DefaultBackend, AudioManagerSettings},
clock::{ClockSpeed, ClockTime},
};
let mut manager = AudioManager::<DefaultBackend>::new(AudioManagerSettings::default())?;
let clock = manager.add_clock(ClockSpeed::TicksPerMinute(120.0))?;
assert_eq!(
ClockTime::from_ticks_f64(&clock, 3.5),
ClockTime {
clock: clock.id(),
ticks: 3,
fraction: 0.5,
},
);Trait Implementations
impl AddAssign<f64> for ClockTime
impl AddAssign<f64> for ClockTime
fn add_assign(&mut self, ticks: f64)
fn add_assign(&mut self, ticks: f64)
Performs the
+= operation. Read moreimpl AddAssign<u64> for ClockTime
impl AddAssign<u64> for ClockTime
fn add_assign(&mut self, ticks: u64)
fn add_assign(&mut self, ticks: u64)
Performs the
+= operation. Read moreimpl PartialOrd for ClockTime
impl PartialOrd for ClockTime
fn partial_cmp(&self, other: &ClockTime) -> Option<Ordering>
fn partial_cmp(&self, other: &ClockTime) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl SubAssign<f64> for ClockTime
impl SubAssign<f64> for ClockTime
fn sub_assign(&mut self, ticks: f64)
fn sub_assign(&mut self, ticks: f64)
Performs the
-= operation. Read moreimpl SubAssign<u64> for ClockTime
impl SubAssign<u64> for ClockTime
fn sub_assign(&mut self, ticks: u64)
fn sub_assign(&mut self, ticks: u64)
Performs the
-= operation. Read moreimpl Copy for ClockTime
impl StructuralPartialEq for ClockTime