Struct jumpy::prelude::kira::sound::static_sound::StaticSoundSettings
pub struct StaticSoundSettings {
pub start_time: StartTime,
pub start_position: PlaybackPosition,
pub loop_region: Option<Region>,
pub reverse: bool,
pub volume: Value<Volume>,
pub playback_rate: Value<PlaybackRate>,
pub panning: Value<f64>,
pub output_destination: OutputDestination,
pub fade_in_tween: Option<Tween>,
}Expand description
Settings for a static sound.
Fields
start_time: StartTimeWhen the sound should start playing.
start_position: PlaybackPositionWhere in the sound playback should start.
loop_region: Option<Region>The portion of the sound that should be looped.
reverse: boolWhether the sound should be played in reverse.
volume: Value<Volume>The volume of the sound.
playback_rate: Value<PlaybackRate>The playback rate of the sound.
Changing the playback rate will change both the speed and the pitch of the sound.
panning: Value<f64>The panning of the sound, where 0 is hard left and 1 is hard right.
output_destination: OutputDestinationThe destination that this sound should be routed to.
fade_in_tween: Option<Tween>An optional fade-in from silence.
Implementations
impl StaticSoundSettings
impl StaticSoundSettings
pub fn new() -> StaticSoundSettings
pub fn new() -> StaticSoundSettings
Creates a new StaticSoundSettings with the default settings.
pub fn start_time(self, start_time: impl Into<StartTime>) -> StaticSoundSettings
pub fn start_time(self, start_time: impl Into<StartTime>) -> StaticSoundSettings
Sets when the sound should start playing.
pub fn start_position(
self,
start_position: impl Into<PlaybackPosition>,
) -> StaticSoundSettings
pub fn start_position( self, start_position: impl Into<PlaybackPosition>, ) -> StaticSoundSettings
Sets where in the sound playback should start.
pub fn reverse(self, reverse: bool) -> StaticSoundSettings
pub fn reverse(self, reverse: bool) -> StaticSoundSettings
Sets whether the sound should be played in reverse.
pub fn loop_region(
self,
loop_region: impl IntoOptionalRegion,
) -> StaticSoundSettings
pub fn loop_region( self, loop_region: impl IntoOptionalRegion, ) -> StaticSoundSettings
Sets the portion of the sound that should be looped.
pub fn volume(self, volume: impl Into<Value<Volume>>) -> StaticSoundSettings
pub fn volume(self, volume: impl Into<Value<Volume>>) -> StaticSoundSettings
Sets the volume of the sound.
pub fn playback_rate(
self,
playback_rate: impl Into<Value<PlaybackRate>>,
) -> StaticSoundSettings
pub fn playback_rate( self, playback_rate: impl Into<Value<PlaybackRate>>, ) -> StaticSoundSettings
Sets the playback rate of the sound.
Changing the playback rate will change both the speed and the pitch of the sound.
pub fn panning(self, panning: impl Into<Value<f64>>) -> StaticSoundSettings
pub fn panning(self, panning: impl Into<Value<f64>>) -> StaticSoundSettings
Sets the panning of the sound, where 0 is hard left and 1 is hard right.
pub fn output_destination(
self,
output_destination: impl Into<OutputDestination>,
) -> StaticSoundSettings
pub fn output_destination( self, output_destination: impl Into<OutputDestination>, ) -> StaticSoundSettings
Sets the destination that this sound should be routed to.
pub fn fade_in_tween(
self,
fade_in_tween: impl Into<Option<Tween>>,
) -> StaticSoundSettings
pub fn fade_in_tween( self, fade_in_tween: impl Into<Option<Tween>>, ) -> StaticSoundSettings
Sets the tween used to fade in the sound from silence.