pub struct StreamingSoundSettings {
pub start_time: StartTime,
pub start_position: PlaybackPosition,
pub loop_region: Option<Region>,
pub volume: Value<Volume>,
pub playback_rate: Value<PlaybackRate>,
pub panning: Value<f64>,
pub output_destination: OutputDestination,
pub fade_in_tween: Option<Tween>,
}Expand description
Settings for a streaming sound.
Fields
start_time: StartTimeWhen the sound should start playing.
start_position: PlaybackPositionWhere in the sound playback should start.
loop_region: Option<Region>The portion of the sound that should be looped.
volume: Value<Volume>The volume of the sound.
playback_rate: Value<PlaybackRate>The playback rate of the sound.
Changing the playback rate will change both the speed and the pitch of the sound.
panning: Value<f64>The panning of the sound, where 0 is hard left and 1 is hard right.
output_destination: OutputDestinationThe destination that this sound should be routed to.
fade_in_tween: Option<Tween>An optional fade-in from silence.
Implementations
impl StreamingSoundSettings
impl StreamingSoundSettings
pub fn new() -> StreamingSoundSettings
pub fn new() -> StreamingSoundSettings
Creates a new StreamingSoundSettings with the default settings.
pub fn start_time(
self,
start_time: impl Into<StartTime>,
) -> StreamingSoundSettings
pub fn start_time( self, start_time: impl Into<StartTime>, ) -> StreamingSoundSettings
Sets when the sound should start playing.
pub fn start_position(
self,
start_position: impl Into<PlaybackPosition>,
) -> StreamingSoundSettings
pub fn start_position( self, start_position: impl Into<PlaybackPosition>, ) -> StreamingSoundSettings
Sets where in the sound playback should start.
pub fn loop_region(
self,
loop_region: impl IntoOptionalRegion,
) -> StreamingSoundSettings
pub fn loop_region( self, loop_region: impl IntoOptionalRegion, ) -> StreamingSoundSettings
Sets the portion of the sound that should be looped.
pub fn volume(self, volume: impl Into<Value<Volume>>) -> StreamingSoundSettings
pub fn volume(self, volume: impl Into<Value<Volume>>) -> StreamingSoundSettings
Sets the volume of the sound.
pub fn playback_rate(
self,
playback_rate: impl Into<Value<PlaybackRate>>,
) -> StreamingSoundSettings
pub fn playback_rate( self, playback_rate: impl Into<Value<PlaybackRate>>, ) -> StreamingSoundSettings
Sets the playback rate of the sound.
Changing the playback rate will change both the speed and the pitch of the sound.
pub fn panning(self, panning: impl Into<Value<f64>>) -> StreamingSoundSettings
pub fn panning(self, panning: impl Into<Value<f64>>) -> StreamingSoundSettings
Sets the panning of the sound, where 0 is hard left and 1 is hard right.
pub fn output_destination(
self,
output_destination: impl Into<OutputDestination>,
) -> StreamingSoundSettings
pub fn output_destination( self, output_destination: impl Into<OutputDestination>, ) -> StreamingSoundSettings
Sets the destination that this sound should be routed to.
pub fn fade_in_tween(
self,
fade_in_tween: impl Into<Option<Tween>>,
) -> StreamingSoundSettings
pub fn fade_in_tween( self, fade_in_tween: impl Into<Option<Tween>>, ) -> StreamingSoundSettings
Sets the tween used to fade in the instance from silence.