Struct jumpy::prelude::AssetLoadProgress
pub struct AssetLoadProgress {
assets_to_load: Arc<AtomicU32>,
assets_downloaded: Arc<AtomicU32>,
assets_loaded: Arc<AtomicU32>,
assets_errored: Arc<AtomicU32>,
event: Arc<Event>,
}Expand description
The progress that has been made loading the game assets.
Fields
assets_to_load: Arc<AtomicU32>assets_downloaded: Arc<AtomicU32>assets_loaded: Arc<AtomicU32>assets_errored: Arc<AtomicU32>event: Arc<Event>Implementations
impl AssetLoadProgress
impl AssetLoadProgress
pub fn inc_to_load(&self)
pub fn inc_to_load(&self)
Increment the number of assets that need to be loaded by one.
pub fn inc_errored(&self)
pub fn inc_errored(&self)
Increment the number of assets that have errored during loading.
pub fn inc_downloaded(&self)
pub fn inc_downloaded(&self)
Increment the number of assets that have been downloaded by one.
pub fn inc_loaded(&self)
pub fn inc_loaded(&self)
Increment the number of assets that have been loaded by one.
pub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Get whether or not all the assets are done loading.
Note: Assets that have errored while loading are still counted as “done loading”.
pub fn loaded(&self) -> u32
pub fn loaded(&self) -> u32
Get the number of assets that have been downloaded and loaded by their asset loaders.
pub fn to_load(&self) -> u32
pub fn to_load(&self) -> u32
Get the number of assets that must be loaded.
Since assets are discovered as they are loaded this number may not be the final asset count and may increase as more assets are discovered.
pub fn downloaded(&self) -> u32
pub fn downloaded(&self) -> u32
Get the number of assets that have had their data downloaded. Once an asset is downloaded we have the raw bytes, but it may not have been processed by it’s asset loader.