Struct jumpy::prelude::AudioCenter
pub struct AudioCenter {
events: VecDeque<AudioEvent>,
music: Option<Audio>,
main_volume_scale: f32,
music_volume_scale: f32,
effects_volume_scale: f32,
music_fade_duration: Duration,
sounds_fade_duration: Duration,
}Expand description
A resource that can be used to control game audios.
Fields
events: VecDeque<AudioEvent>music: Option<Audio>main_volume_scale: f32music_volume_scale: f32effects_volume_scale: f32music_fade_duration: Durationsounds_fade_duration: DurationImplementations
impl AudioCenter
impl AudioCenter
pub fn push_event(&mut self, event: AudioEvent)
pub fn push_event(&mut self, event: AudioEvent)
Push an audio event to the queue for later processing.
pub fn music_state(&self) -> Option<PlaybackState>
pub fn music_state(&self) -> Option<PlaybackState>
Get the playback state of the current music.
pub fn play_sound(&mut self, sound_source: Handle<AudioSource>, volume: f64)
pub fn play_sound(&mut self, sound_source: Handle<AudioSource>, volume: f64)
Play a sound. These are usually short audios that indicate something happened in game, e.g. a player jump, an explosion, etc. Volume is scaled by both main_volume_scale, and effects_volume_scale.
pub fn play_music(
&mut self,
sound_source: Handle<AudioSource>,
volume: f64,
loop_music: bool,
)
pub fn play_music( &mut self, sound_source: Handle<AudioSource>, volume: f64, loop_music: bool, )
Plays music, forcibly stopping any current music. Volume is scaled by both main_volume_scale and music_volume_scale.
pub fn play_music_advanced(
&mut self,
sound_source: Handle<AudioSource>,
volume: f64,
loop_music: bool,
reverse: bool,
start_position: f64,
playback_rate: f64,
skip_restart: bool,
)
pub fn play_music_advanced( &mut self, sound_source: Handle<AudioSource>, volume: f64, loop_music: bool, reverse: bool, start_position: f64, playback_rate: f64, skip_restart: bool, )
Plays music with advanced settings. Volume is scaled by both main_volume_scale and music_volume_scale.
Parameters
sound_source- The handle for the audio source to playvolume- The volume to play the music at (0.0 to 1.0)loop_music- Whether the music should loop indefinitelyreverse- Whether to play the audio in reversestart_position- The position in seconds to start playback fromplayback_rate- The playback rate (1.0 is normal speed, 0.5 is half speed, 2.0 is double speed)skip_restart- If true, won’t restart the music if it’s already playing the same track
pub fn play_music_custom(
&mut self,
sound_source: Handle<AudioSource>,
sound_settings: StaticSoundSettings,
skip_restart: bool,
)
pub fn play_music_custom( &mut self, sound_source: Handle<AudioSource>, sound_settings: StaticSoundSettings, skip_restart: bool, )
Plays music with custom StaticSoundSettings. Volume is scaled by both main_volume_scale and music_volume_scale.
pub fn set_main_volume_scale(&mut self, main: f32)
pub fn set_main_volume_scale(&mut self, main: f32)
Sets the volume scale for main audio within the range of 0.0 to 1.0. The main volume scale impacts all other volume scales.
pub fn set_music_volume_scale(&mut self, music: f32)
pub fn set_music_volume_scale(&mut self, music: f32)
Sets the volume scale for music within the range of 0.0 to 1.0.
pub fn set_effects_volume_scale(&mut self, effects: f32)
pub fn set_effects_volume_scale(&mut self, effects: f32)
Sets the volume scale for effects within the range of 0.0 to 1.0.
pub fn set_volume_scales(&mut self, main: f32, music: f32, effects: f32)
pub fn set_volume_scales(&mut self, main: f32, music: f32, effects: f32)
Sets the volume scales for main, music, and effects within the range of 0.0 to 1.0.
pub fn main_volume_scale(&self) -> f32
pub fn main_volume_scale(&self) -> f32
Returns the main volume scale (which impacts all other volume scales).
pub fn music_volume_scale(&self) -> f32
pub fn music_volume_scale(&self) -> f32
Returns the music volume scale.
pub fn effects_volume_scale(&self) -> f32
pub fn effects_volume_scale(&self) -> f32
Returns the volume scale for sound effects.
pub fn music_fade_duration(&self) -> Duration
pub fn music_fade_duration(&self) -> Duration
Returns the duration for music fade out.
pub fn set_music_fade_duration(&mut self, duration: Duration)
pub fn set_music_fade_duration(&mut self, duration: Duration)
Sets the duration for music fade out.
pub fn sounds_fade_duration(&self) -> Duration
pub fn sounds_fade_duration(&self) -> Duration
Returns the duration for audio fade out.
pub fn set_sounds_fade_duration(&mut self, duration: Duration)
pub fn set_sounds_fade_duration(&mut self, duration: Duration)
Sets the duration for audio fade out.
pub fn stop_music(&mut self, fade_out: bool)
pub fn stop_music(&mut self, fade_out: bool)
Stops the currently playing music
fade_out- If true, fades out the music using the Audio Center’s music fade duration. If false, stops the sounds instantly.
pub fn stop_all_sounds(&mut self, fade_out: bool)
pub fn stop_all_sounds(&mut self, fade_out: bool)
Stops all currently playing sounds.
fade_out- If true, fades out the sounds using the Audio Center’s sounds fade duration. If false, stops the sounds instantly.