Struct jumpy::prelude::RngGenerator
pub struct RngGenerator {
internal_generator: AtomicRng,
}Expand description
Resource that produces deterministic pseudo-random numbers/strings.
Access in a system with Res<RngGenerator>.
Fields
internal_generator: AtomicRngImplementations
impl RngGenerator
impl RngGenerator
pub fn new(seed: u64) -> RngGenerator
pub fn new(seed: u64) -> RngGenerator
Creates a new RngGenerator, initializing it with the provided seed
pub fn gen_u8_range<R>(&mut self, range: R) -> u8where
R: RangeBounds<u8>,
pub fn gen_u8_range<R>(&mut self, range: R) -> u8where
R: RangeBounds<u8>,
Generate a random u8 within the given range
pub fn gen_i8_range<R>(&mut self, range: R) -> i8where
R: RangeBounds<i8>,
pub fn gen_i8_range<R>(&mut self, range: R) -> i8where
R: RangeBounds<i8>,
Generate a random i8 within the given range
pub fn gen_u16_range<R>(&mut self, range: R) -> u16where
R: RangeBounds<u16>,
pub fn gen_u16_range<R>(&mut self, range: R) -> u16where
R: RangeBounds<u16>,
Generate a random u16 within the given range
pub fn gen_i16_range<R>(&mut self, range: R) -> i16where
R: RangeBounds<i16>,
pub fn gen_i16_range<R>(&mut self, range: R) -> i16where
R: RangeBounds<i16>,
Generate a random i16 within the given range
pub fn gen_u32_range<R>(&mut self, range: R) -> u32where
R: RangeBounds<u32>,
pub fn gen_u32_range<R>(&mut self, range: R) -> u32where
R: RangeBounds<u32>,
Generate a random u32 within the given range
pub fn gen_i32_range<R>(&mut self, range: R) -> i32where
R: RangeBounds<i32>,
pub fn gen_i32_range<R>(&mut self, range: R) -> i32where
R: RangeBounds<i32>,
Generate a random i32 within the given range
pub fn gen_u64_range<R>(&mut self, range: R) -> u64where
R: RangeBounds<u64>,
pub fn gen_u64_range<R>(&mut self, range: R) -> u64where
R: RangeBounds<u64>,
Generate a random u64 within the given range
pub fn gen_i64_range<R>(&mut self, range: R) -> i64where
R: RangeBounds<i64>,
pub fn gen_i64_range<R>(&mut self, range: R) -> i64where
R: RangeBounds<i64>,
Generate a random i64 within the given range
pub fn gen_usize_range<R>(&mut self, range: R) -> usizewhere
R: RangeBounds<usize>,
pub fn gen_usize_range<R>(&mut self, range: R) -> usizewhere
R: RangeBounds<usize>,
Generate a random usize within the given range
pub fn gen_isize_range<R>(&mut self, range: R) -> isizewhere
R: RangeBounds<isize>,
pub fn gen_isize_range<R>(&mut self, range: R) -> isizewhere
R: RangeBounds<isize>,
Generate a random isize within the given range
pub fn gen_f32_range<R>(&mut self, range: R) -> f32where
R: RangeBounds<f32>,
pub fn gen_f32_range<R>(&mut self, range: R) -> f32where
R: RangeBounds<f32>,
Generate a random f32 within the given range
pub fn gen_f64_range<R>(&mut self, range: R) -> f64where
R: RangeBounds<f64>,
pub fn gen_f64_range<R>(&mut self, range: R) -> f64where
R: RangeBounds<f64>,
Generate a random f64 within the given range
pub fn gen_vec2_range<R1, R2>(&mut self, x_range: R1, y_range: R2) -> Vec2
pub fn gen_vec2_range<R1, R2>(&mut self, x_range: R1, y_range: R2) -> Vec2
Generate a random Vec2 within the given ranges for each component
pub fn gen_vec3_range<R1, R2, R3>(
&mut self,
x_range: R1,
y_range: R2,
z_range: R3,
) -> Vec3
pub fn gen_vec3_range<R1, R2, R3>( &mut self, x_range: R1, y_range: R2, z_range: R3, ) -> Vec3
Generate a random Vec3 within the given ranges for each component
pub fn shuffle_vec<T>(&mut self, vec: &mut [T])
pub fn shuffle_vec<T>(&mut self, vec: &mut [T])
Shuffle a Vec in place
pub fn shuffle_svec<T>(&mut self, svec: &mut SVec<T>)where
T: HasSchema,
pub fn shuffle_svec<T>(&mut self, svec: &mut SVec<T>)where
T: HasSchema,
Shuffle an SVec in place
pub fn shuffle_vecdeque<T>(&mut self, deque: &mut VecDeque<T>)
pub fn shuffle_vecdeque<T>(&mut self, deque: &mut VecDeque<T>)
Shuffle a VecDeque in place
pub fn gen_alphabetic(&mut self) -> char
pub fn gen_alphabetic(&mut self) -> char
Generates a random char in ranges a-z and A-Z.
pub fn gen_alphanumeric(&mut self) -> char
pub fn gen_alphanumeric(&mut self) -> char
Generates a random char in ranges a-z, A-Z and 0-9.
pub fn gen_lowercase(&mut self) -> char
pub fn gen_lowercase(&mut self) -> char
Generates a random char in the range a-z.
pub fn gen_uppercase(&mut self) -> char
pub fn gen_uppercase(&mut self) -> char
Generates a random char in the range A-Z.
pub fn gen_digit(&mut self, radix: u8) -> char
pub fn gen_digit(&mut self, radix: u8) -> char
Generate a random digit in the given radix.
Digits are represented by chars in ranges 0-9 and a-z.
Panics
Panics if the radix is zero or greater than 36.
pub fn gen_char<R>(&mut self, bounds: R) -> charwhere
R: RangeBounds<char>,
pub fn gen_char<R>(&mut self, bounds: R) -> charwhere
R: RangeBounds<char>,
pub fn gen_random_ascii_char(&mut self) -> char
pub fn gen_random_ascii_char(&mut self) -> char
Generate a random printable ASCII character
pub fn gen_random_ascii_string(&mut self, length: u64) -> String
pub fn gen_random_ascii_string(&mut self, length: u64) -> String
Generate a random ASCII string of the specified length
pub fn gen_chance(&mut self, success_rate: f64) -> bool
pub fn gen_chance(&mut self, success_rate: f64) -> bool
Returns a boolean, where success_rate represents the chance to return a true value,
with 0.0 being no chance and 1.0 will always return true.
pub fn gen_sample<'a, T>(&mut self, list: &'a [T]) -> Option<&'a T>
pub fn gen_sample<'a, T>(&mut self, list: &'a [T]) -> Option<&'a T>
Samples a random item from a slice of values.
pub fn gen_sample_iter<T>(&mut self, list: T) -> Option<<T as Iterator>::Item>where
T: Iterator,
pub fn gen_sample_iter<T>(&mut self, list: T) -> Option<<T as Iterator>::Item>where
T: Iterator,
Samples a random item from an iterator of values.
pub fn gen_sample_mut<'a, T>(&mut self, list: &'a mut [T]) -> Option<&'a mut T>
pub fn gen_sample_mut<'a, T>(&mut self, list: &'a mut [T]) -> Option<&'a mut T>
Samples a random &mut item from a slice of values.
pub fn gen_sample_multiple<'a, T>(
&mut self,
list: &'a [T],
amount: usize,
) -> Vec<&'a T>
pub fn gen_sample_multiple<'a, T>( &mut self, list: &'a [T], amount: usize, ) -> Vec<&'a T>
Samples multiple unique items from a slice of values.
pub fn gen_sample_multiple_mut<'a, T>(
&mut self,
list: &'a mut [T],
amount: usize,
) -> Vec<&'a mut T>
pub fn gen_sample_multiple_mut<'a, T>( &mut self, list: &'a mut [T], amount: usize, ) -> Vec<&'a mut T>
Samples multiple unique items from a mutable slice of values.
pub fn gen_sample_multiple_iter<T>(
&mut self,
list: T,
amount: usize,
) -> Vec<<T as Iterator>::Item>where
T: Iterator,
pub fn gen_sample_multiple_iter<T>(
&mut self,
list: T,
amount: usize,
) -> Vec<<T as Iterator>::Item>where
T: Iterator,
Samples multiple unique items from an iterator of values.
pub fn gen_weighted_sample<'a, T, F>(
&mut self,
list: &'a [T],
weight_sampler: F,
) -> Option<&'a T>
pub fn gen_weighted_sample<'a, T, F>( &mut self, list: &'a [T], weight_sampler: F, ) -> Option<&'a T>
Stochastic Acceptance implementation of Roulette Wheel weighted selection.