Struct jumpy::prelude::UntypedResourceSet
pub struct UntypedResourceSet {
resources: Vec<UntypedResource>,
}Expand description
Utility container for storing set of UntypedResource.
Cloning
Fields
resources: Vec<UntypedResource>Implementations
impl UntypedResourceSet
impl UntypedResourceSet
pub fn insert_resource<T>(&mut self, resource: T)where
T: HasSchema,
pub fn insert_resource<T>(&mut self, resource: T)where
T: HasSchema,
Insert a startup resource. On stage / session startup (first step), will be inserted into World.
If already exists, will be overwritten.
pub fn init_resource<T>(&mut self) -> RefMut<'_, T>
pub fn init_resource<T>(&mut self) -> RefMut<'_, T>
Init resource with default, and return mutable ref for modification. If already exists, returns mutable ref to existing resource.
pub fn resource_mut<T>(&self) -> Option<RefMut<'_, T>>where
T: HasSchema,
pub fn resource_mut<T>(&self) -> Option<RefMut<'_, T>>where
T: HasSchema,
Get mutable reference to startup resource if found.
pub fn insert_empty<T>(&mut self)where
T: HasSchema,
pub fn insert_empty<T>(&mut self)where
T: HasSchema,
Insert an UntypedResource with empty cell for [Schema] of T.
If resource already exists for this schema, overwrite it with empty.
pub fn resources(&self) -> &Vec<UntypedResource>
pub fn resources(&self) -> &Vec<UntypedResource>
Get immutable ref to Vec of resources
pub fn insert_on_world(&self, world: &mut World, remove_empty: bool)
pub fn insert_on_world(&self, world: &mut World, remove_empty: bool)
Insert resources in world. If resource already exists, overwrites it.
If remove_empty is set, if resource cell is empty, it will remove the
resource from cell on world.