#[repr(C)]pub struct UVec2 {
pub x: u32,
pub y: u32,
}Expand description
A 2-dimensional vector.
Fields
x: u32y: u32Implementations
sourceimpl UVec2
impl UVec2
sourcepub fn select(mask: BVec2, if_true: UVec2, if_false: UVec2) -> UVec2
pub fn select(mask: BVec2, if_true: UVec2, if_false: UVec2) -> UVec2
Creates a vector from the elements in if_true and if_false, selecting which to use
for each element of self.
A true element in the mask uses the corresponding element from if_true, and false
uses the element from if_false.
sourcepub const fn from_array(a: [u32; 2]) -> UVec2
pub const fn from_array(a: [u32; 2]) -> UVec2
Creates a new vector from an array.
sourcepub const fn from_slice(slice: &[u32]) -> UVec2
pub const fn from_slice(slice: &[u32]) -> UVec2
Creates a vector from the first 2 values in slice.
Panics
Panics if slice is less than 2 elements long.
sourcepub fn write_to_slice(self, slice: &mut [u32])
pub fn write_to_slice(self, slice: &mut [u32])
Writes the elements of self to the first 2 elements in slice.
Panics
Panics if slice is less than 2 elements long.
sourcepub const fn extend(self, z: u32) -> UVec3
pub const fn extend(self, z: u32) -> UVec3
Creates a 3D vector from self and the given z value.
sourcepub fn dot_into_vec(self, rhs: UVec2) -> UVec2
pub fn dot_into_vec(self, rhs: UVec2) -> UVec2
Returns a vector where every component is the dot product of self and rhs.
sourcepub fn min(self, rhs: UVec2) -> UVec2
pub fn min(self, rhs: UVec2) -> UVec2
Returns a vector containing the minimum values for each element of self and rhs.
In other words this computes [self.x.min(rhs.x), self.y.min(rhs.y), ..].
sourcepub fn max(self, rhs: UVec2) -> UVec2
pub fn max(self, rhs: UVec2) -> UVec2
Returns a vector containing the maximum values for each element of self and rhs.
In other words this computes [self.x.max(rhs.x), self.y.max(rhs.y), ..].
sourcepub fn clamp(self, min: UVec2, max: UVec2) -> UVec2
pub fn clamp(self, min: UVec2, max: UVec2) -> UVec2
Component-wise clamping of values, similar to u32::clamp.
Each element in min must be less-or-equal to the corresponding element in max.
Panics
Will panic if min is greater than max when glam_assert is enabled.
sourcepub fn min_element(self) -> u32
pub fn min_element(self) -> u32
Returns the horizontal minimum of self.
In other words this computes min(x, y, ..).
sourcepub fn max_element(self) -> u32
pub fn max_element(self) -> u32
Returns the horizontal maximum of self.
In other words this computes max(x, y, ..).
sourcepub fn cmpeq(self, rhs: UVec2) -> BVec2
pub fn cmpeq(self, rhs: UVec2) -> BVec2
Returns a vector mask containing the result of a == comparison for each element of
self and rhs.
In other words, this computes [self.x == rhs.x, self.y == rhs.y, ..] for all
elements.
sourcepub fn cmpne(self, rhs: UVec2) -> BVec2
pub fn cmpne(self, rhs: UVec2) -> BVec2
Returns a vector mask containing the result of a != comparison for each element of
self and rhs.
In other words this computes [self.x != rhs.x, self.y != rhs.y, ..] for all
elements.
sourcepub fn cmpge(self, rhs: UVec2) -> BVec2
pub fn cmpge(self, rhs: UVec2) -> BVec2
Returns a vector mask containing the result of a >= comparison for each element of
self and rhs.
In other words this computes [self.x >= rhs.x, self.y >= rhs.y, ..] for all
elements.
sourcepub fn cmpgt(self, rhs: UVec2) -> BVec2
pub fn cmpgt(self, rhs: UVec2) -> BVec2
Returns a vector mask containing the result of a > comparison for each element of
self and rhs.
In other words this computes [self.x > rhs.x, self.y > rhs.y, ..] for all
elements.
sourcepub fn cmple(self, rhs: UVec2) -> BVec2
pub fn cmple(self, rhs: UVec2) -> BVec2
Returns a vector mask containing the result of a <= comparison for each element of
self and rhs.
In other words this computes [self.x <= rhs.x, self.y <= rhs.y, ..] for all
elements.
sourcepub fn cmplt(self, rhs: UVec2) -> BVec2
pub fn cmplt(self, rhs: UVec2) -> BVec2
Returns a vector mask containing the result of a < comparison for each element of
self and rhs.
In other words this computes [self.x < rhs.x, self.y < rhs.y, ..] for all
elements.
sourcepub fn length_squared(self) -> u32
pub fn length_squared(self) -> u32
Computes the squared length of self.
sourcepub fn as_i64vec2(&self) -> I64Vec2
pub fn as_i64vec2(&self) -> I64Vec2
Casts all elements of self to i64.
sourcepub fn as_u64vec2(&self) -> U64Vec2
pub fn as_u64vec2(&self) -> U64Vec2
Casts all elements of self to u64.
sourcepub const fn wrapping_add(self, rhs: UVec2) -> UVec2
pub const fn wrapping_add(self, rhs: UVec2) -> UVec2
Returns a vector containing the wrapping addition of self and rhs.
In other words this computes [self.x.wrapping_add(rhs.x), self.y.wrapping_add(rhs.y), ..].
sourcepub const fn wrapping_sub(self, rhs: UVec2) -> UVec2
pub const fn wrapping_sub(self, rhs: UVec2) -> UVec2
Returns a vector containing the wrapping subtraction of self and rhs.
In other words this computes [self.x.wrapping_sub(rhs.x), self.y.wrapping_sub(rhs.y), ..].
sourcepub const fn wrapping_mul(self, rhs: UVec2) -> UVec2
pub const fn wrapping_mul(self, rhs: UVec2) -> UVec2
Returns a vector containing the wrapping multiplication of self and rhs.
In other words this computes [self.x.wrapping_mul(rhs.x), self.y.wrapping_mul(rhs.y), ..].
sourcepub const fn wrapping_div(self, rhs: UVec2) -> UVec2
pub const fn wrapping_div(self, rhs: UVec2) -> UVec2
Returns a vector containing the wrapping division of self and rhs.
In other words this computes [self.x.wrapping_div(rhs.x), self.y.wrapping_div(rhs.y), ..].
sourcepub const fn saturating_add(self, rhs: UVec2) -> UVec2
pub const fn saturating_add(self, rhs: UVec2) -> UVec2
Returns a vector containing the saturating addition of self and rhs.
In other words this computes [self.x.saturating_add(rhs.x), self.y.saturating_add(rhs.y), ..].
sourcepub const fn saturating_sub(self, rhs: UVec2) -> UVec2
pub const fn saturating_sub(self, rhs: UVec2) -> UVec2
Returns a vector containing the saturating subtraction of self and rhs.
In other words this computes [self.x.saturating_sub(rhs.x), self.y.saturating_sub(rhs.y), ..].
sourcepub const fn saturating_mul(self, rhs: UVec2) -> UVec2
pub const fn saturating_mul(self, rhs: UVec2) -> UVec2
Returns a vector containing the saturating multiplication of self and rhs.
In other words this computes [self.x.saturating_mul(rhs.x), self.y.saturating_mul(rhs.y), ..].
sourcepub const fn saturating_div(self, rhs: UVec2) -> UVec2
pub const fn saturating_div(self, rhs: UVec2) -> UVec2
Returns a vector containing the saturating division of self and rhs.
In other words this computes [self.x.saturating_div(rhs.x), self.y.saturating_div(rhs.y), ..].