#[repr(C)]pub struct OPoint<T, D>{
pub coords: Matrix<T, D, Const<1>, <DefaultAllocator as Allocator<T, D>>::Buffer>,
}Expand description
A point in an euclidean space.
The difference between a point and a vector is only semantic. See the user guide
for details on the distinction. The most notable difference that vectors ignore translations.
In particular, an Isometry2 or Isometry3 will
transform points by applying a rotation and a translation on them. However, these isometries
will only apply rotations to vectors (when doing isometry * vector, the translation part of
the isometry is ignored).
Construction
- From individual components
new… - Swizzling
xx,yxz… - Other construction methods
origin,from_slice,from_homogeneous…
Transformation
Transforming a point by an Isometry, rotation, etc. can be
achieved by multiplication, e.g., isometry * point or rotation * point. Some of these transformation
may have some other methods, e.g., isometry.inverse_transform_point(&point). See the documentation
of said transformations for details.
Fields
coords: Matrix<T, D, Const<1>, <DefaultAllocator as Allocator<T, D>>::Buffer>The coordinates of this point, i.e., the shift from the origin.
Implementations
sourceimpl<T, D> OPoint<T, D>
impl<T, D> OPoint<T, D>
sourcepub fn map<T2, F>(&self, f: F) -> OPoint<T2, D>
pub fn map<T2, F>(&self, f: F) -> OPoint<T2, D>
Returns a point containing the result of f applied to each of its entries.
Example
let p = Point2::new(1.0, 2.0);
assert_eq!(p.map(|e| e * 10.0), Point2::new(10.0, 20.0));
// This works in any dimension.
let p = Point3::new(1.1, 2.1, 3.1);
assert_eq!(p.map(|e| e as u32), Point3::new(1, 2, 3));sourcepub fn apply<F>(&mut self, f: F)
pub fn apply<F>(&mut self, f: F)
Replaces each component of self by the result of a closure f applied on it.
Example
let mut p = Point2::new(1.0, 2.0);
p.apply(|e| *e = *e * 10.0);
assert_eq!(p, Point2::new(10.0, 20.0));
// This works in any dimension.
let mut p = Point3::new(1.0, 2.0, 3.0);
p.apply(|e| *e = *e * 10.0);
assert_eq!(p, Point3::new(10.0, 20.0, 30.0));sourcepub fn to_homogeneous(
&self,
) -> Matrix<T, <D as DimNameAdd<Const<1>>>::Output, Const<1>, <DefaultAllocator as Allocator<T, <D as DimNameAdd<Const<1>>>::Output>>::Buffer>where
T: One,
D: DimNameAdd<Const<1>>,
DefaultAllocator: Allocator<T, <D as DimNameAdd<Const<1>>>::Output>,
pub fn to_homogeneous(
&self,
) -> Matrix<T, <D as DimNameAdd<Const<1>>>::Output, Const<1>, <DefaultAllocator as Allocator<T, <D as DimNameAdd<Const<1>>>::Output>>::Buffer>where
T: One,
D: DimNameAdd<Const<1>>,
DefaultAllocator: Allocator<T, <D as DimNameAdd<Const<1>>>::Output>,
Converts this point into a vector in homogeneous coordinates, i.e., appends a 1 at the
end of it.
This is the same as .into().
Example
let p = Point2::new(10.0, 20.0);
assert_eq!(p.to_homogeneous(), Vector3::new(10.0, 20.0, 1.0));
// This works in any dimension.
let p = Point3::new(10.0, 20.0, 30.0);
assert_eq!(p.to_homogeneous(), Vector4::new(10.0, 20.0, 30.0, 1.0));sourcepub fn lerp(&self, rhs: &OPoint<T, D>, t: T) -> OPoint<T, D>
pub fn lerp(&self, rhs: &OPoint<T, D>, t: T) -> OPoint<T, D>
Linear interpolation between two points.
Returns self * (1.0 - t) + rhs.coords * t, i.e., the linear blend of the points
self and rhs using the scalar value t.
The value for a is not restricted to the range [0, 1].
Examples:
let a = Point3::new(1.0, 2.0, 3.0);
let b = Point3::new(10.0, 20.0, 30.0);
assert_eq!(a.lerp(&b, 0.1), Point3::new(1.9, 3.8, 5.7));sourcepub fn from_coordinates(
coords: Matrix<T, D, Const<1>, <DefaultAllocator as Allocator<T, D>>::Buffer>,
) -> OPoint<T, D>
👎Deprecated: Use Point::from(vector) instead.
pub fn from_coordinates( coords: Matrix<T, D, Const<1>, <DefaultAllocator as Allocator<T, D>>::Buffer>, ) -> OPoint<T, D>
Creates a new point with the given coordinates.
sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
The dimension of this point.
Example
let p = Point2::new(1.0, 2.0);
assert_eq!(p.len(), 2);
// This works in any dimension.
let p = Point3::new(10.0, 20.0, 30.0);
assert_eq!(p.len(), 3);sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the point contains no elements.
Example
let p = Point2::new(1.0, 2.0);
assert!(!p.is_empty());sourcepub fn stride(&self) -> usize
👎Deprecated: This methods is no longer significant and will always return 1.
pub fn stride(&self) -> usize
The stride of this point. This is the number of buffer element separating each component of this point.
sourcepub fn iter(
&self,
) -> MatrixIter<'_, T, D, Const<1>, <DefaultAllocator as Allocator<T, D>>::Buffer> ⓘ
pub fn iter( &self, ) -> MatrixIter<'_, T, D, Const<1>, <DefaultAllocator as Allocator<T, D>>::Buffer> ⓘ
Iterates through this point coordinates.
Example
let p = Point3::new(1.0, 2.0, 3.0);
let mut it = p.iter().cloned();
assert_eq!(it.next(), Some(1.0));
assert_eq!(it.next(), Some(2.0));
assert_eq!(it.next(), Some(3.0));
assert_eq!(it.next(), None);sourcepub unsafe fn get_unchecked(&self, i: usize) -> &T
pub unsafe fn get_unchecked(&self, i: usize) -> &T
Gets a reference to i-th element of this point without bound-checking.
sourcepub fn iter_mut(
&mut self,
) -> MatrixIterMut<'_, T, D, Const<1>, <DefaultAllocator as Allocator<T, D>>::Buffer> ⓘ
pub fn iter_mut( &mut self, ) -> MatrixIterMut<'_, T, D, Const<1>, <DefaultAllocator as Allocator<T, D>>::Buffer> ⓘ
Mutably iterates through this point coordinates.
Example
let mut p = Point3::new(1.0, 2.0, 3.0);
for e in p.iter_mut() {
*e *= 10.0;
}
assert_eq!(p, Point3::new(10.0, 20.0, 30.0));sourcepub unsafe fn get_unchecked_mut(&mut self, i: usize) -> &mut T
pub unsafe fn get_unchecked_mut(&mut self, i: usize) -> &mut T
Gets a mutable reference to i-th element of this point without bound-checking.
sourcepub unsafe fn swap_unchecked(&mut self, i1: usize, i2: usize)
pub unsafe fn swap_unchecked(&mut self, i1: usize, i2: usize)
Swaps two entries without bound-checking.
sourceimpl<T, D> OPoint<T, D>
impl<T, D> OPoint<T, D>
sourceimpl<T, D> OPoint<T, D>
impl<T, D> OPoint<T, D>
Other construction methods
sourcepub fn origin() -> OPoint<T, D>where
T: Zero,
pub fn origin() -> OPoint<T, D>where
T: Zero,
Creates a new point with all coordinates equal to zero.
Example
// This works in any dimension.
// The explicit crate::<f32> type annotation may not always be needed,
// depending on the context of type inference.
let pt = Point2::<f32>::origin();
assert!(pt.x == 0.0 && pt.y == 0.0);
let pt = Point3::<f32>::origin();
assert!(pt.x == 0.0 && pt.y == 0.0 && pt.z == 0.0);sourcepub fn from_slice(components: &[T]) -> OPoint<T, D>
pub fn from_slice(components: &[T]) -> OPoint<T, D>
Creates a new point from a slice.
Example
let data = [ 1.0, 2.0, 3.0 ];
let pt = Point2::from_slice(&data[..2]);
assert_eq!(pt, Point2::new(1.0, 2.0));
let pt = Point3::from_slice(&data);
assert_eq!(pt, Point3::new(1.0, 2.0, 3.0));sourcepub fn from_homogeneous(
v: Matrix<T, <D as DimNameAdd<Const<1>>>::Output, Const<1>, <DefaultAllocator as Allocator<T, <D as DimNameAdd<Const<1>>>::Output>>::Buffer>,
) -> Option<OPoint<T, D>>where
T: Scalar + Zero + One + ClosedDiv,
D: DimNameAdd<Const<1>>,
DefaultAllocator: Allocator<T, <D as DimNameAdd<Const<1>>>::Output>,
pub fn from_homogeneous(
v: Matrix<T, <D as DimNameAdd<Const<1>>>::Output, Const<1>, <DefaultAllocator as Allocator<T, <D as DimNameAdd<Const<1>>>::Output>>::Buffer>,
) -> Option<OPoint<T, D>>where
T: Scalar + Zero + One + ClosedDiv,
D: DimNameAdd<Const<1>>,
DefaultAllocator: Allocator<T, <D as DimNameAdd<Const<1>>>::Output>,
Creates a new point from its homogeneous vector representation.
In practice, this builds a D-dimensional points with the same first D component as v
divided by the last component of v. Returns None if this divisor is zero.
Example
let coords = Vector4::new(1.0, 2.0, 3.0, 1.0);
let pt = Point3::from_homogeneous(coords);
assert_eq!(pt, Some(Point3::new(1.0, 2.0, 3.0)));
// All component of the result will be divided by the
// last component of the vector, here 2.0.
let coords = Vector4::new(1.0, 2.0, 3.0, 2.0);
let pt = Point3::from_homogeneous(coords);
assert_eq!(pt, Some(Point3::new(0.5, 1.0, 1.5)));
// Fails because the last component is zero.
let coords = Vector4::new(1.0, 2.0, 3.0, 0.0);
let pt = Point3::from_homogeneous(coords);
assert!(pt.is_none());
// Works also in other dimensions.
let coords = Vector3::new(1.0, 2.0, 1.0);
let pt = Point2::from_homogeneous(coords);
assert_eq!(pt, Some(Point2::new(1.0, 2.0)));sourceimpl<T, const D: usize> OPoint<T, Const<D>>
impl<T, const D: usize> OPoint<T, Const<D>>
Swizzling