Trait jumpy::prelude::kira::effect::EffectBuilder

pub trait EffectBuilder {
    type Handle;

    // Required method
    fn build(self) -> (Box<dyn Effect>, Self::Handle);
}
Configures an effect.

Required Associated Types

type Handle

Allows the user to control the effect from gameplay code.

Required Methods

fn build(self) -> (Box<dyn Effect>, Self::Handle)

Creates the effect and a handle to the effect.

Implementors